function sim_createModel2_0;

%-------------------------------------------------------------------------
% User interface for setting up a mat-file containing structure of data
% (for detailed describe see sim_evalScans) for evaluating simulated fMRI
% data.
% 
%
% It calls:  - sim_getROI       .. computes ROI's pixels
%            - sim_evalScans    .. evaluates scans
%            - sim_trend        .. computes trend time series
%            - sim_getSignals   .. definition of signals
%
% ver. 2.0  6/2008
%-------------------------------------------------------------------------

ver = spm('ver');
p = path;
spm5ind = findstr(p,'spm5;');
if isempty(spm5ind)
    l{1} = '';
    l{2} = 'This program should be run under SPM5.';
    l{3} = ['Current active SPM version is ' ver '. Please, change MATLAB search path.'];
    disp(char(l))
    return
end
    


spm_defaults

%% default values

sim_dir = fileparts(mfilename('fullpath'));

FS = [];
RoiDir = fullfile(sim_dir,'ROI');
ActiveLB = 'MAN';
def_pattern = fullfile(sim_dir,'EPI.img');
Model.ROIs = [];
Model.Noise.Drift.val = 1;
Model.Noise.Drift.coef = [1 -0.005];
Model.Noise.Drift.consider = 0;
Model.Noise.lfn.val = 1;
Model.Noise.lfn.cutoff = 128;
Model.Noise.lfn.w = 0.1;
Model.Noise.lfn.consider = 0;
Model.Noise.Ar.consider = 0;
Model.Noise.Ar.val = 0.2;
Model.Noise.Ar.h1 = 1;
Model.Noise.Ar.h2 = 0.05;
Model.Noise.gn.val = 1;
Model.Noise.gn.w = 0.1;
Model.Noise.gn.consider = 0;
Model.Noise.residn.val = 1;
Model.Noise.residn.consider = 0;
Model.File.prefix = 'fMRI_';
Model.Features.GI = 100;
Model.Features.nscan = 100;
Model.File.saveSigImgs = 0;
Model.File.saveNoiseImgs = 0;
Model.File.saveResidImgs = 0;

%%
%--------  overall constants  ------------
ColorA = [0.8 0.8 0.8];
ColorB = [0.93 0.91 0.85];
ButtDim = [ 100 35 ];


%%
%---------  figure features  -------------

ScSize = get(0,'ScreenSize');
figWidth = 900;
figHeigh = 700;
figPos = [ 100 100 figWidth figHeigh];

FS.fig = figure('unit','pixel','Position',figPos,'Resize','off','Name','fMRI Data Simulator',...
    'NumberTitle','off','Color',ColorB);
FS.SetMenu = uimenu('Label','Settings');
FS.ROIDirMenu = uimenu(FS.SetMenu,'Label','Set ROI dir','CallBack',@SetRoiDir);

%---------  signals area ------------

FrameModelPos = [ 10 530 180 160 ];
ButGetModelPos = [ 45 540 ButtDim];
LBoxColPos = [ 20 585 160 80 ];
TextColPos = [ 20 670 100 15 ];
TextColLinePos = [ 90 675 50 14 ];
AxesColPos = [ 220 555 320 115 ];

FS.FrameModel = uicontrol(FS.fig,'Units','pixel','Style','Frame',...
    'Position',FrameModelPos,'BackGroundColor',ColorA);
FS.TextCol = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextColPos,'String','Signals','BackGroundColor',ColorA,...
    'FontWeight','bold','HorizontalAlignment','Left');
FS.TextColLine = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextColLinePos,'String','________','BackGroundColor',ColorA,...
    'FontWeight','bold','HorizontalAlignment','Left','ForeGroundColor',[0 0 1]);
FS.LBoxCol = uicontrol(FS.fig,'Units','pixel','Style','ListBox',...
    'Position',LBoxColPos,'CallBack',@Column);
FS.ButGetModel = uicontrol(FS.fig,'Units','pixel','Style','pushButton','String','Define Signals',...
    'Position',ButGetModelPos,'CallBack',@getModel);
FS.AxesCol = axes('Units','pixel','Position',AxesColPos,'Visible','on',...
    'Color',ColorB,'Box','off');

%---------- pattern area -------------------

FramePatPos = [560 550 330 140];
TextPatPos = [570 670 100 15 ];
RBPatFilePos = [570 640 100 15];
EditPatFilePos = [ 570 610 150 20 ];
ButPatFilePos = [ 595 564 ButtDim];
RBPatSpPos = [740 640 100 15];
EditPatSpdPos = [ 810 610 70 20 ];
EditPatSpvsPos = [ 810 587 70 20 ];
EditPatSpcPos = [ 810 564 70 20 ];
TextPatSpdPos = [741 612 60 15 ];
TextPatSpvsPos = [741 589 60 15 ];
TextPatSpcPos = [741 566 60 15];

FS.FramePat = uicontrol(FS.fig,'Units','pixel','Style','Frame',...
    'Position',FramePatPos,'BackGroundColor',ColorA);
FS.TextPat = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextPatPos,'String','Pattern scan','BackGroundColor',ColorA,...
    'FontWeight','bold','HorizontalAlignment','Left');
FS.RBPatFile = uicontrol(FS.fig,'Units','pixel','Style','RadioButton','BackGroundColor',ColorA,...
    'String','from file','Position',RBPatFilePos,'Value',1,'CallBack',@ChBoxPatFileSd);
FS.EditPatFile = uicontrol(FS.fig,'Units','pixel','Style','Edit','Enable','Inactive',...
    'Position',EditPatFilePos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.ButPatFile = uicontrol(FS.fig,'Units','pixel','Style','pushButton','String','Load pattern',...
    'Position',ButPatFilePos,'CallBack',@loadPattern);
FS.RBPatSp = uicontrol(FS.fig,'Units','pixel','Style','RadioButton','BackGroundColor',ColorA,...
    'String','defined space','Position',RBPatSpPos,'CallBack',@ChBoxPatFileSd,'Value',0);
FS.EditPatSpd = uicontrol(FS.fig,'Units','pixel','Style','Edit','String','53 63 46','CallBack',@SdEdit,...
    'Position',EditPatSpdPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.EditPatSpvs = uicontrol(FS.fig,'Units','pixel','Style','Edit','String','3 3 3','CallBack',@SdEdit,...
    'Position',EditPatSpvsPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.EditPatSpc = uicontrol(FS.fig,'Units','pixel','Style','Edit','String','27 38 18','CallBack',@SdEdit,...
    'Position',EditPatSpcPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.TextPatSpd = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextPatSpdPos,'String','dim [vox]','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.TextPatSpvs = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextPatSpvsPos,'String','voxel size','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.TextPatSpc = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextPatSpcPos,'String','center [vox]','BackGroundColor',ColorA,'HorizontalAlignment','Left');


%---------- ROIs area ---------

FrameROIManPos = [ 10 310 540 210];

TextROIPos = [ 20 500 100 15 ];
LBoxROIManPos = [ 20 365 160 130 ];
ButNewROIPos = [ 20 320 75 35];
ButROIToModPos = [ 105 320 75 35];

TextROIModPos = [ 230 500 100 15 ];
TextROIModLinePos = [ 320 505 80 14 ];
LBoxROIModPos = [ 230 365 160 130 ]; 
ButRemROIPos = [ 260 320 ButtDim];

TextWPos = [ 400 472 50 15];
EditWPos = [ 450 470 90 20 ];
TextMPos = [ 400 442 80 15 ];
EditMPos = [ 480 440 60 20 ];
TextPPos = [ 400 412 60 15 ];
PopUpPPos = [ 460 410 80 20 ];
TextPaPos = [ 400 382 90 15 ];
EditPaPos = [ 480 380 60 20 ];
TextPbPos = [ 400 352 50 15 ];
EditPbPos = [ 450 350 90 20 ];
TextFiPos = [ 400 322 60 15 ];
EditFiPos = [ 450 320 90 20 ];

FS.FrameROIMan = uicontrol(FS.fig,'Units','pixel','Style','Frame',...
    'Position',FrameROIManPos,'BackGroundColor',ColorA);
FS.TextROI = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextROIPos,'String','ROIs','BackGroundColor',ColorA,...
    'FontWeight','bold','HorizontalAlignment','Left');
FS.LBoxROIMan = uicontrol(FS.fig,'Units','pixel','Style','ListBox',...
    'Position',LBoxROIManPos,'CallBack',@LBROIMan);
FS.ButNewROI = uicontrol(FS.fig,'Units','pixel','Style','pushButton','String','New ROI',...
    'Position',ButNewROIPos,'CallBack',@NewROI);
FS.ButROIToMod = uicontrol(FS.fig,'Units','pixel','Style','pushButton','String','To model',...
    'Position',ButROIToModPos,'CallBack',@ROIToMod,'Enable','off');
FS.TextROIMod = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextROIModPos,'String','ROIs in model','BackGroundColor',ColorA,...
    'FontWeight','bold','HorizontalAlignment','Left');
FS.TextROIModLine = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextROIModLinePos,'String','________','BackGroundColor',ColorA,...
    'FontWeight','bold','HorizontalAlignment','Left','ForeGroundColor',[1 0 0]);
FS.LBoxROIMod = uicontrol(FS.fig,'Units','pixel','Style','ListBox',...
    'Position',LBoxROIModPos,'CallBack',@LBROIMod);
FS.ButRemROI = uicontrol(FS.fig,'Units','pixel','Style','pushButton','String','Remove ROI',...
    'Position',ButRemROIPos,'CallBack',@RemROI);
FS.TextWMod = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextWPos,'String','Weights','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditWMod = uicontrol(FS.fig,'Units','pixel','Style','Edit',...
    'Position',EditWPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left','CallBack',@WMod);
FS.TextMMod = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextMPos,'String','Magnitude [%]','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditMMod = uicontrol(FS.fig,'Units','pixel','Style','Edit',...
    'Position',EditMPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left','CallBack',@MMod);
FS.TextPMod = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextPPos,'String','ROI Profile','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.PopUpPMod = uicontrol(FS.fig,'Units','pixel','Style','PopUp',...
    'Position',PopUpPPos,'String','Constant|Linear|Gauss','BackGroundColor',ColorB,...
    'HorizontalAlignment','Left','Callback',@PMod);
FS.TextPaMod = uicontrol(FS.fig,'Units','pixel','Style','Text','Enable','off',...
    'Position',TextPaPos,'String','Decay [1/mm]','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditPaMod = uicontrol(FS.fig,'Units','pixel','Style','Edit','Enable','off',...
    'Position',EditPaPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left','CallBack',@PaMod);
FS.TextPbMod = uicontrol(FS.fig,'Units','pixel','Style','Text','Enable','off',...
    'Position',TextPbPos,'String','RVMRP','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditPbMod = uicontrol(FS.fig,'Units','pixel','Style','Edit','ToolTipString','Relative value in the most remote point of ROI',...
    'Position',EditPbPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left','CallBack',@MMod,'Enable','inactive');
FS.TextFiMod = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextFiPos,'String','Angle []','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditFiMod = uicontrol(FS.fig,'Units','pixel','Style','Edit',...
    'Position',EditFiPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left','CallBack',@FiMod);


%---------- model management area ---------

FrameModMan1Pos = [ 10 100 220 200 ];
FrameModMan2Pos = [ 230 10 660 290 ];
FrameModMan3Pos = [ 228 101 4 198 ];
TextNoisePos = [20 200 100 15];


ButModManDOPos = [ 780 20 100 75];
ButModManLoadPos = [ 670 20 ButtDim];
ButModManSavePos = [ 670 60 ButtDim];

ChBDriftPos = [20 175 80 15];
TextDriftAPos = [20 117 100 15];
EditDriftAPos = [185 115 35 20];
TextDriftBPos = [20 147 55 15];
EditDriftBPos = [100 145 120 20];
AxesDriftPos = [35 30 180 55];

ChBlfnPos = [240 175 140 15];
TextlfnOCPos = [240 147 100 15];
EditlfnOCPos = [335 145 35 20];
TextlfnCOfPos = [380 147 55 15];
EditlfnCOfPos = [430 145 35 20];
TextlfnwPos = [240 117 150 15];
EditlfnwPos = [430 115 35 20];

ChBArPos = [240 275 140 15];
TextArPos = [240 247 100 15];
EditArPos = [335 245 35 20];
Texth1Pos = [240 217 55 15];
Edith1Pos = [335 215 35 20];
Texth2Pos = [380 217 55 15];
Edith2Pos = [430 215 35 20];

ChBgnPos = [240 80 150 15];
TextgfOCPos = [240 52 55 15];
EditgfOCPos = [430 50 35 20];
TextgfwPos = [240 22 150 15];
EditgfwPos = [430 20 35 20];

ChBresidnPos = [485 175 150 15];
TextresidnPos = [485 147 55 15];
EditresidnvalPos = [615 145 35 20];

TextSaveVolPos = [485 80 150 15];
ChBSigImgsPos = [485 60 150 15];
ChBNoiseImgsPos = [485 40 150 15];
ChBResidImgsPos = [485 20 150 15];

TextPrefixPos = [670 147 100 15];
EditPrefixPos = [820 145 60 20];
TextGScalePos = [670 117 100 15];
EditGScalePos = [820 115 60 20];


FS.FrameModMan1 = uicontrol(FS.fig,'Units','pixel','Style','Frame',...
    'Position',FrameModMan1Pos,'BackGroundColor',ColorA);
FS.FrameModMan2 = uicontrol(FS.fig,'Units','pixel','Style','Frame',...
    'Position',FrameModMan2Pos,'BackGroundColor',ColorA);
FS.FrameModMan3 = uicontrol(FS.fig,'Units','pixel','Style','Frame',...
    'Position',FrameModMan3Pos,'BackGroundColor',ColorA,'ForeGroundColor',ColorA);
FS.TextNoise = uicontrol(FS.fig,'Units','pixel','Style','Text','FontWeight','bold',...
    'Position',TextNoisePos,'String','Noise definition','BackGroundColor',ColorA,'HorizontalAlignment','Left');

FS.ButModManDO = uicontrol(FS.fig,'Units','pixel','Style','pushButton','String','DO',...
    'Position',ButModManDOPos,'CallBack',@DO,'Enable','off','ForeGroundColor',[1 0.5 0.25]);
FS.ButModManLoad = uicontrol(FS.fig,'Units','pixel','Style','pushButton','String','Load settings',...
    'Position',ButModManLoadPos,'CallBack',@LoadModel);
FS.ButModManSave = uicontrol(FS.fig,'Units','pixel','Style','pushButton','String','Save settings',...
    'Position',ButModManSavePos,'CallBack',@SaveModel);

FS.ChBDrift = uicontrol(FS.fig,'Units','pixel','Style','CheckBox','String','Drift','FontWeight','bold',...
    'Position',ChBDriftPos,'Value',Model.Noise.Drift.consider,'BackGroundColor',ColorA,'CallBack',@RBNoise);
FS.TextDriftA = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextDriftAPos,'String','overal change [%]','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditDriftA = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g',Model.Noise.Drift.val),'CallBack',@Drift,...
    'Position',EditDriftAPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.TextDriftB = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextDriftBPos,'String','coeficients','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditDriftB = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g ',Model.Noise.Drift.coef),'CallBack',@Drift,...
    'Position',EditDriftBPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.AxesDrift = axes('Units','pixel','Position',AxesDriftPos,'Color',ColorB,'Box','off');

FS.ChBlfn = uicontrol(FS.fig,'Units','pixel','Style','CheckBox','String','Low frequency noise','FontWeight','bold',...
    'Position',ChBlfnPos,'Value',Model.Noise.lfn.consider,'BackGroundColor',ColorA,'CallBack',@RBNoise);
FS.TextlfnOC = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextlfnOCPos,'String','overal change [%]','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditlfnOC = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g',Model.Noise.lfn.val),'CallBack',@Noise,...
    'Position',EditlfnOCPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.TextlfnCOf = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextlfnCOfPos,'String','cut off [s]','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditlfnCOf = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%d',Model.Noise.lfn.cutoff),'CallBack',@Noise,...
    'Position',EditlfnCOfPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.Textlfnw = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextlfnwPos,'String','multiplicative noise coefficient','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.Editlfnw = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g',Model.Noise.lfn.w),'CallBack',@Noise,...
    'Position',EditlfnwPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');

FS.ChBAr = uicontrol(FS.fig,'Units','pixel','Style','CheckBox','String','AR(1) model','FontWeight','bold',...
    'Position',ChBArPos,'Value',Model.Noise.Ar.consider,'BackGroundColor',ColorA,'CallBack',@RBNoise);
FS.TextAr = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextArPos,'String','AR coefficient','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditAr = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g',Model.Noise.Ar.val),'CallBack',@Noise,...
    'Position',EditArPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.Texth1 = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',Texth1Pos,'String','h(1)','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.Edith1 = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%d',Model.Noise.Ar.h1),'CallBack',@Noise,...
    'Position',Edith1Pos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.Texth2 = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',Texth2Pos,'String','h(2)','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.Edith2 = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g',Model.Noise.Ar.h2),'CallBack',@Noise,...
    'Position',Edith2Pos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');

FS.ChBgn = uicontrol(FS.fig,'Units','pixel','Style','CheckBox','String','Gaussian noise','FontWeight','bold',...
    'Position',ChBgnPos,'Value',Model.Noise.gn.consider,'BackGroundColor',ColorA,'CallBack',@RBNoise);
FS.TextgnOC = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextgfOCPos,'String','sigma','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditgnOC = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g',Model.Noise.gn.val),'CallBack',@Noise,...
    'Position',EditgfOCPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.Textgnw = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextgfwPos,'String','multiplicative noise coefficient','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.Editgnw = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g',Model.Noise.gn.w),'CallBack',@Noise,...
    'Position',EditgfwPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');

%FS.ChBresidn = uicontrol(FS.fig,'Units','pixel','Style','CheckBox','String','Residual noise','FontWeight','bold',...
%    'Position',ChBresidnPos,'Value',Model.Noise.residn.consider,'BackGroundColor',ColorA,'CallBack',@RBNoise);
%FS.Textresidn = uicontrol(FS.fig,'Units','pixel','Style','Text',...
%    'Position',TextresidnPos,'String','multiplier','BackGroundColor',ColorA,'HorizontalAlignment','Left');
%FS.Editresidnval = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g',Model.Noise.Drift.val),'CallBack',@Noise,...
 %   'Position',EditresidnvalPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');


FS.TextSaveVol = uicontrol(FS.fig,'Units','pixel','Style','Text','FontWeight','bold',...
    'Position',TextSaveVolPos,'String','Save also','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.ChBSigImgs = uicontrol(FS.fig,'Units','pixel','Style','CheckBox','String','signal images',...
    'Position',ChBSigImgsPos,'Value',Model.File.saveSigImgs,'BackGroundColor',ColorA,'CallBack',@SaveImgs);
FS.ChBNoiseImgs = uicontrol(FS.fig,'Units','pixel','Style','CheckBox','String','noise images',...
    'Position',ChBNoiseImgsPos,'Value',Model.File.saveNoiseImgs,'BackGroundColor',ColorA,'CallBack',@SaveImgs);
FS.ChBResidImgs = uicontrol(FS.fig,'Units','pixel','Style','CheckBox','String','residual noise images',...
    'Position',ChBResidImgsPos,'Value',Model.File.saveResidImgs,'BackGroundColor',ColorA,'CallBack',@SaveImgs);


FS.TextPrefix = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextPrefixPos,'String','Prefix for scans','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditPrefix = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',Model.File.prefix,'CallBack',@Prefix,...
    'Position',EditPrefixPos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');
FS.TextGScale = uicontrol(FS.fig,'Units','pixel','Style','Text',...
    'Position',TextGScalePos,'String','Global scaling value','BackGroundColor',ColorA,'HorizontalAlignment','Left');
FS.EditGScale = uicontrol(FS.fig,'Units','pixel','Style','Edit','String',sprintf('%g',Model.Features.GI),'CallBack',@GScaleVal,...
    'Position',EditGScalePos,'BackGroundColor',ColorB,'HorizontalAlignment','Left');


%---------- oviews area ---------

TextMmPos = [780 474 25 15];
TextMmXPos = [805 504 10 15];
TextMmYPos = [805 474 10 15];
TextMmZPos = [805 444 10 15];
EditMmXPos = [820 500 50 20];
EditMmYPos = [820 470 50 20];
EditMmZPos = [820 440 50 20];

FS.OV_Axes1 = axes('Color','k','Units','pixels','Position',[10 10 10 10]);
FS.OV_Axes2 = axes('Color','k','Units','pixels','Position',[10 10 10 10]);
FS.OV_Axes3 = axes('Color','k','Units','pixels','Position',[10 10 10 10]);
FS.OV_TextMm = uicontrol(FS.fig,'Style','Text','Units','pixel','Position',TextMmPos,'String','mm');
FS.OV_TextMmX = uicontrol(FS.fig,'Style','Text','Units','pixel','Position',TextMmXPos,'String','x');
FS.OV_TextMmY = uicontrol(FS.fig,'Style','Text','Units','pixel','Position',TextMmYPos,'String','y');
FS.OV_TextMmZ = uicontrol(FS.fig,'Style','Text','Units','pixel','Position',TextMmZPos,'String','z');
FS.OV_EditMmX = uicontrol(FS.fig,'Style','Edit','Units','pixel','Position',EditMmXPos,'String','0',...
    'Callback',@OVclick);
FS.OV_EditMmY = uicontrol(FS.fig,'Style','Edit','Units','pixel','Position',EditMmYPos,'String','0',...
    'Callback',@OVclick);
FS.OV_EditMmZ = uicontrol(FS.fig,'Style','Edit','Units','pixel','Position',EditMmZPos,'String','0',...
    'Callback',@OVclick);

guidata(FS.fig,FS)

%-----------end of setting uicontrol------------------------

%%
%-----------set app data---------------------
setappdata(FS.fig,'ScSize',ScSize)
setappdata(FS.fig,'def_pattern',def_pattern)
setappdata(FS.fig,'RoiDir',RoiDir)
setappdata(FS.fig,'ColorB',ColorB)
setappdata(FS.fig,'ColorA',ColorA)
setappdata(FS.fig,'OV_image',[]);
setappdata(FS.fig,'OV_pattern',[]);
setappdata(FS.fig,'OV_imgData',[]);


if exist(def_pattern)
    Model.Pattern = spm_vol(def_pattern);
    set(FS.EditPatFile,'String',def_pattern);
    set(FS.EditPatFile,'TooltipString',def_pattern);
    setappdata(FS.fig,'Model',Model)
    oviews('init',def_pattern);
else
    pattern = spm_select(1,'image','Select pattern scan');
    Model.Pattern = spm_vol(pattern);
    set(FS.EditPatFile,'String',pattern);
    set(FS.EditPatFile,'TooltipString',pattern);
    setappdata(FS.fig,'Model',Model)
    oviews('init',pattern);
end

%% Initialize of controls on sturt up
ReadROIs;
set(FS.LBoxROIMan,'Value',1);
LBROIMan(FS.LBoxROIMan)



%%
%------------------------
% loads new pattern scan
%------------------------
function loadPattern(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
pattern = spm_select(1,'image','Select pattern scan');
Model.Pattern = spm_vol(pattern);
setappdata(FS.fig,'Model',Model);
set(FS.EditPatFile,'String',pattern);
set(FS.EditPatFile,'TooltipString',pattern);
setappdata(FS.fig,'OV_xyz',[])
oviews('init',pattern,400);


%%
%------------------------------------------
% calls spm_getSignals; creates regressors 
%------------------------------------------
function getModel(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
try
    delete(FS.AxesCol_LBoxColLine)
    delete(FS.AxesCol_LBoxROIModLine)
end

FS.sigfig = figure;

try
    if isfield(FS,'sigpars')
        sim_getSignals(FS.sigfig,FS.fig,FS.sigpars);
    else
        sim_getSignals(FS.sigfig,FS.fig);
    end
catch
    disp('Error in sim_getSignal.mat  .....')
    return
end

waitfor(FS.sigfig)

FS = guidata(FS.fig);

n = FS.sigpars.NSig;
Model.Features.nReg = n;
for ii = 1:n
    colNames{ii} = [ 'sig ' num2str(ii) ];
end
if n > 0
    Model.X = FS.sig;
    set(FS.LBoxCol,'Value',1);
    set(FS.LBoxCol,'String',char(colNames));
    set(FS.ButROIToMod,'Enable','on');
    Model.Features.nscan = FS.sigpars.NS;
    Model.Features.RT = FS.sigpars.TR;
    setappdata(FS.fig,'Model',Model);
    setappdata(FS.fig,'Xaxis',0:Model.Features.nscan-1);
    Column(FS.LBoxCol,[])
end
Model.ROIs = [];
setappdata(FS.fig,'Model',Model);
Drift(FS.EditDriftB);
ReadModROIs

%%
%------------------------
% plots chosen regressor
%------------------------
function Column(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
col = get(hObject,'Value');
lines = get(FS.AxesCol,'Children');
if col > 0
    switch hObject
        case FS.LBoxCol
            data = Model.X(:,col);
            if length(lines)<1
                subplot(FS.AxesCol)
                FS.AxesCol_LBoxColLine = plot(getappdata(FS.fig,'Xaxis'),data);
            else
                set(FS.AxesCol_LBoxColLine,'YData',data)
            end
        case FS.LBoxROIMod
            data = Model.X*Model.ROIs(col).ROI.w;
            if length(lines)<2
               subplot(FS.AxesCol),  hold on, FS.AxesCol_LBoxROIModLine = plot(getappdata(FS.fig,'Xaxis'),data,'r'); hold off;
            else
                set(FS.AxesCol_LBoxROIModLine,'YData',data)
            end
    end
    set(FS.AxesCol,'Color',getappdata(FS.fig,'ColorB'))
    set(FS.AxesCol,'Box','off')
    set(get(FS.AxesCol,'XLabel'),'String','time [scan]')
    XLim = get(FS.AxesCol,'XLim');
    YLim = get(FS.AxesCol,'YLim');
    Ypos = YLim(1)+0.2*(YLim(2)-YLim(1));
    set(get(FS.AxesCol,'XLabel'),'Position',[XLim(2) Ypos 1])
    set(get(FS.AxesCol,'XLabel'),'HorizontalAlignment','right')
    set(get(FS.AxesCol,'XLabel'),'BackGroundColor',getappdata(FS.fig,'ColorB'))
    guidata(FS.fig,FS)
end


%%
%------------------------
% creates new ROI
%------------------------
function NewROI(hObject, eventdata)
FS = guidata(hObject);
spm('CreateIntWin','off');
MaskFileName='';
spm_input('','-1','d','ROI Definition... ');
ROItype = spm_input('Select type of ROI','+1','b','Sphere|Elipse|Box|Line|Mask',['s' 'e' 'b' 'l' 'm'],1);
switch ROItype
    case 's'
        c = spm_input('Center [mm]','+1','r','0 0 0',[1 3]);
        r = spm_input('Radius [mm]','+1','r','5',[1 1]);
    case 'e'
        c = spm_input('Center [mm]','+1','r','0 0 0',[1 3]);
        r = spm_input('3 Dimensional Radius [mm]','+1','r','10 10 5',[1 3]);
    case 'b'
        c = spm_input('Center [mm]','+1','r','0 0 0',[1 3]);
        r = spm_input('Dimension [mm]','+1','r','10 10 10',[1 3]);
    case 'l'
        c = spm_input('Origin [mm]','+1','r','0 0 0',[1 3]);
        r = spm_input('End [mm]','+1','r','20 20 0',[3 1]);
    case 'm'
        MaskFileName=spm_select(1,'image','Select binary mask file (1 = within ROI)','.',0);
        c = [0 0 0];
        r = [0 0 0];
        %load file with mask
        V = spm_vol(MaskFileName);
        [Y,XYZ] = spm_read_vols(V);
        aXYZ=XYZ';          
        xXYZ=[];
        xXYZmm=[];
        for i=1:size(aXYZ,1)
            mmsou = [aXYZ(i,:) 1];
            voxsou= (inv(V.mat)*mmsou')';
            if Y(voxsou(1),voxsou(2),voxsou(3))>0
                xXYZ = [xXYZ; voxsou(1:3)];
                xXYZmm = [xXYZmm; mmsou(1:3)];
            end
        end  
        nv=size(xXYZ,1);
        f=ones(nv,1);        
        cog = CenterOfGravity(f, xXYZmm);
        if ~isnan(cog)
            c=cog;  % center of gravity as parameter A
        end
end
delete(spm_figure('FindWin','Interactive'));
if ROItype=='m'
    [mfpathstr,mfname,mfext,mfversn] = fileparts(MaskFileName);
    nameOfRoi = mfname;
else
    nameOfRoi = [ROItype '-' sprintf('%d_',round(c)) '_' sprintf('%d_',round(r))];    
    nameOfRoi = nameOfRoi(1:end-1);
end
ROI.name = ROItype;
ROI.parA = c;
ROI.parB = r;
ROI.parFileName = MaskFileName;
i = 0;
while exist([getappdata(FS.fig,'RoiDir') nameOfRoi '.mat'],'file')
    i = i+1;
    nameOfRoi = [nameOfRoi sprintf('__%d',i)];
end
save([getappdata(FS.fig,'RoiDir') '\' nameOfRoi '.mat'],'ROI');
image = getappdata(FS.fig,'OV_image');
setappdata(FS.fig,'OV_xyz',sim_getROI(image.mat,image.dim,ROI));
setappdata(FS.fig,'OV_pos',transform(ROI.parA));

ReadROIs;
oviews('redraw');
   

%%
%------------------
%------------------
function p = transform(pos)
FS = guidata(gcf);
image = getappdata(FS.fig,'OV_image');
p = inv(image.mat)*[pos';1];
p = p(1:3)';


%%
%------------------
%------------------
function p = itransform(pos)
FS = guidata(gcf);
image = getappdata(FS.fig,'OV_image');
p = image.mat*[pos';1];
p = p(1:3)';


%%
%------------------------
%------------------------
function SetRoiDir(hObject, eventdata)
FS = guidata(hObject);
setappdata(FS.fig,'RoiDir',spm_select(1,'dir','Select ROI directory'));
ReadROIs;


%%
%------------------------------------------------------
% reads ROIs from ROI directory and list them in ListBox
%------------------------------------------------------
function ReadROIs
FS = guidata(gcf);
ROIs = [];
oldpath=pwd;
cd(getappdata(FS.fig,'RoiDir'))
files = dir('*.mat');
if ~length(files) 
    set(FS.LBoxROIMan,'String',[]);
    cd(oldpath);
    setappdata(FS.fig,'ROIs',ROIs)
    return;
end
j = 1;
for i = 1:length(files)
    if (~files(i).isdir)
        load([pwd '\' files(i).name]);
        if exist('ROI','var')
            ROIs{j} = ROI;
            names{j} = files(i).name;
            clear ROI
            j = j+1;
        end
    end
end
setappdata(FS.fig,'ROIs',ROIs)
set(FS.LBoxROIMan,'String',char(names))
cd(oldpath);


%%
%--------------------------------
% displays chosen ROI over pattern
%--------------------------------
function LBROIMan(hObject, eventdata)
FS = guidata(hObject);
ROIs = getappdata(FS.fig,'ROIs');
Model = getappdata(FS.fig,'Model');
ind = get(FS.LBoxROIMan,'Value');
if ind > 0
    ROI = ROIs{ind};
    setappdata(FS.fig,'OV_xyz',[]);
    setappdata(FS.fig,'OV_xyz',sim_getROI(Model.Pattern.mat,Model.Pattern.dim,ROI));  
    setappdata(FS.fig,'OV_pos',transform(ROI.parA));
    if ~(hObject==FS.RBPatSp)
        oviews('redraw')
    end
    setappdata(FS.fig,'ActiveLB','MAN');
end


%%
%------------------------
% adds chosen ROI to model
%------------------------
function ROIToMod(hObject, eventdata)
FS = guidata(hObject);
ROIs = getappdata(FS.fig,'ROIs');
Model = getappdata(FS.fig,'Model');
ind = get(FS.LBoxROIMan,'Value');
if ind > 0
    ROI = ROIs{ind};
    spm('CreateIntWin','off');
    spm_input('',1,'d','ROI Features... ');
    ROI.w = spm_input('Signal definition ','+1','r','',[ Model.Features.nReg 1 ]);
    ROI.m = spm_input('Magnitude (percents of underlay image mean)','+1','r','3',[ 1 1 ]);
    ROI.rw = 'c';%spm_input('ROI profile','+1','b','Constant|Linear|Gaussian',[ 'c', 'l', 'g' ],1);
    ROI.fi = [0 0 0];
    delete(spm_figure('FindWin','Interactive'));
    n = length(Model.ROIs);
    Model.ROIs(n+1).ROI = ROI;
    set(FS.ButModManDO,'Enable','on');
end
set(FS.LBoxROIMod,'Value',n+1);
setappdata(FS.fig,'Model',Model);
ReadModROIs

%%
%-----------------------------------------
% reads model ROIs and list them in ListBox
%-----------------------------------------
function ReadModROIs
FS = guidata(gcf);
Model = getappdata(FS.fig,'Model');
names = cell(0);
n = length(Model.ROIs);
for i = 1:n
    ROI = Model.ROIs(i).ROI;
    names{i} = [ROI.name '-' sprintf('%d_',round(ROI.parA)) '_' sprintf('%d_',round(ROI.parB))];
    names{i} = names{i}(1:end-1);
end
set(FS.LBoxROIMod,'String',char(names));
LBROIMod


%%
%------------------------------
% removes chosen ROI from model
%------------------------------
function RemROI(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
ind = get(FS.LBoxROIMod,'Value');
n = length(Model.ROIs);
if (n==0) | (n==1)
    set(FS.ButModManDO,'Enable','off');
    try
        delete(FS.AxesCol_LBoxROIModLine)
        guidata(FS.fig,FS)
    end
end
if n>0
    Model.ROIs(ind).ROI = Model.ROIs(n).ROI;
    Model.ROIs = Model.ROIs(1:n-1);
end
setappdata(FS.fig,'Model',Model)

ReadModROIs


%%
%---------------------------------
% displays chosen ROI over pattern
%---------------------------------
function LBROIMod(hObject, eventdata)
FS = guidata(gcf);
Model = getappdata(FS.fig,'Model');
ind = get(FS.LBoxROIMod,'Value');
if (ind > 0) & ~isempty(Model.ROIs)
    ROI = Model.ROIs(ind).ROI;
    setappdata(FS.fig,'OV_xyz',sim_getROI(Model.Pattern.mat,Model.Pattern.dim,ROI));
    setappdata(FS.fig,'OV_pos',transform(ROI.parA))
    oviews('redraw')
    set(FS.EditWMod,'String',sprintf('%g ',ROI.w));
    set(FS.EditMMod,'String',sprintf('%g ',ROI.m));
    set(FS.EditFiMod,'String',sprintf('%g ',ROI.fi));
    switch ROI.rw
        case 'c'
            v = 1;
        case 'l'
            v = 2;
        case 'g'
            v = 3;
    end
    set(FS.PopUpPMod,'Value',v);
    PMod;
    setappdata(FS.fig,'ActiveLB','MOD');
    Column(FS.LBoxROIMod,[])
else
    set(FS.EditWMod,'String','')
    set(FS.EditWMod,'String','')
    set(FS.EditWMod,'String','0 0 0')
end


%%
%------------------------
%------------------------
function PMod(hObject, eventdata)
FS = guidata(gcf);
Model = getappdata(FS.fig,'Model');
ind = get(FS.LBoxROIMod,'Value');
n = length(Model.ROIs);
p = ['c' 'l' 'g'];
if n>0
    ind1 = get(FS.PopUpPMod,'Value');
    Model.ROIs(ind).ROI.rw = p(ind1);
    switch ind1
        case 1
            set(FS.TextPaMod,'Enable','off');
            set(FS.TextPbMod,'Enable','off');
            set(FS.EditPaMod,'Enable','off');
            set(FS.EditPbMod,'Enable','off');
        case 2
            set(FS.TextPaMod,'Enable','on');
            set(FS.TextPbMod,'Enable','on');
            set(FS.EditPaMod,'Enable','on');
            set(FS.EditPbMod,'Enable','inactive');
            set(FS.TextPaMod,'String','Decay [1/mm]');
            if isfield(Model.ROIs(ind).ROI,'rwpar')
                set(FS.EditPaMod,'String',sprintf('%2.3f',Model.ROIs(ind).ROI.rwpar));
                setappdata(FS.fig,'Model',Model)
                DecayVal(2,Model.ROIs(ind).ROI.rwpar,ind);
            else
                set(FS.EditPaMod,'String','0.1');
                Model.ROIs(ind).ROI.rwpar = 0.1;
                setappdata(FS.fig,'Model',Model)
                DecayVal(2,0.1,ind);
            end
        case 3
            set(FS.TextPaMod,'Enable','on');
            set(FS.TextPbMod,'Enable','on');
            set(FS.EditPaMod,'Enable','on');
            set(FS.EditPbMod,'Enable','inactive');
            set(FS.TextPaMod,'String','FWHM');
            set(FS.EditPaMod,'String','5');
            if isfield(Model.ROIs(ind).ROI,'rwpar')
                set(FS.EditPaMod,'String',sprintf('%2.3f',Model.ROIs(ind).ROI.rwpar));
                setappdata(FS.fig,'Model',Model)
                DecayVal(3,Model.ROIs(ind).ROI.rwpar,ind);
            else
                set(FS.EditPaMod,'String','5');
                Model.ROIs(ind).ROI.rwpar = 5;
                setappdata(FS.fig,'Model',Model)
                DecayVal(3,5,ind);
            end
    end
end


%%
%------------------------
%------------------------
function DecayVal(shape,val,n)
FS = guidata(gcf);
Model = getappdata(FS.fig,'Model');
ROI = Model.ROIs(n).ROI;
switch ROI.name
    case {'s', 'e'}
        d = max(ROI.parB);
    case 'b'
        d = 0.5*sqrt(sum(ROI.parB.^2));
    case 'l'
        d = sqrt(sum((ROI.parA-ROI.parB').^2));
end
if shape==2
    rv = 1-val*d;
else
    sigma = val/(2*sqrt(log(4)));
    rv = exp(-d^2/(2*sigma^2));
end
if rv<0, rv = 0; end
set(FS.EditPbMod,'String',sprintf('%2.2f',rv));        


%%
%------------------------
%------------------------
function PaMod(hObject, eventdata)
FS = guidata(gcf);
Model = getappdata(FS.fig,'Model');
temp = sscanf(get(FS.EditPaMod,'String'),'%f');
if isempty(temp), return, end;
ind = get(FS.LBoxROIMod,'Value');
Model.ROIs(ind).ROI.rwpar = temp;
setappdata(FS.fig,'Model',Model)
DecayVal(get(FS.PopUpPMod,'Value'),temp,ind);


%%
%------------------------
%------------------------
function MMod(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
ind = get(FS.LBoxROIMod,'Value');
n = length(Model.ROIs);
if n>0
    m = sscanf(get(FS.EditMMod,'String'),'%f');
    if ~isempty(m) & (length(m) == 1)
        Model.ROIs(ind).ROI.m = m;
        setappdata(FS.fig,'Model',Model)
    end
end
set(FS.LBoxROIMod,'Value',ind);

ReadModROIs


%%
%------------------------
%------------------------
function FiMod(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
ind = get(FS.LBoxROIMod,'Value');
n = length(Model.ROIs);
if n>0
    fi = sscanf(get(FS.EditFiMod,'String'),'%d');
    if ~isempty(fi) & (length(fi) == 3)
        Model.ROIs(ind).ROI.fi = fi;
        setappdata(FS.fig,'Model',Model)
    end
end
set(FS.LBoxROIMod,'Value',ind);
ReadModROIs



%%
%------------------------
%------------------------
function WMod(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
ind = get(FS.LBoxROIMod,'Value');
n = length(Model.ROIs);
if n>0
    w = sscanf(get(FS.EditWMod,'String'),'%f');
    if ~isempty(w) & (length(w) == length(Model.X(1,:)))
        Model.ROIs(ind).ROI.w = w;
        setappdata(FS.fig,'Model',Model)
    end
end
set(FS.LBoxROIMod,'Value',ind);
ReadModROIs


%%
%------------------------
%------------------------
function SdEdit(hObject, eventdata)
FS = guidata(hObject);
v = sscanf(get(hObject,'String'),'%f');
if ~(length(v) == 3) | sum(v<=0)
    switch hObject
        case FS.EditPatSpd
            set(hObject,'String','53 63 46');
        case FS.EditPatSpvs
            set(hObject,'String','3 3 3');
        case FS.EditPatSpc
            set(hObject,'String','27 38 18');
    end
end
if get(FS.RBPatSp,'Value')
    ChBoxPatFileSd(FS.RBPatSp,[])
end


%%
%------------------------
%------------------------
function ChBoxPatFileSd(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
ROIs = getappdata(FS.fig,'ROIs');
switch hObject
    case FS.RBPatFile
        set(FS.RBPatFile,'Value',1);
        set(FS.RBPatSp,'Value',0);
        Model.Pattern = spm_vol(get(FS.EditPatFile,'String'));
        p = Model.Pattern.fname;
        set(FS.ButPatFile,'Enable','on');
    case FS.RBPatSp
        set(FS.RBPatFile,'Value',0);
        set(FS.RBPatSp,'Value',1);
        set(FS.ButPatFile,'Enable','off');
        Model.Pattern = [];
        v = sscanf(get(FS.EditPatSpd,'String'),'%f');
        Model.Pattern.dim = [round(v)' 4];
        v = sscanf(get(FS.EditPatSpvs,'String'),'%f');
        Model.Pattern.mat = eye(4);
        Model.Pattern.mat(1,1) = -v(1);
        Model.Pattern.mat(2,2) = v(2);
        Model.Pattern.mat(3,3) = v(3);
        c = sscanf(get(FS.EditPatSpc,'String'),'%f');
        Model.Pattern.mat(1,4) = v(1)*c(1);
        Model.Pattern.mat(2,4) = -v(2)*c(2);
        Model.Pattern.mat(3,4) = -v(3)*c(3);
        Model.Pattern.fname = 'defined space';
        Model.Pattern.pinfo = [1 0 0]';
        p = Model.Pattern; 
end
setappdata(FS.fig,'Model',Model)
guidata(FS.fig,FS)
if strcmp('MOD',getappdata(FS.fig,'ActiveLB'))
    if length(Model.ROIs)
        i = get(FS.LBoxROIMod,'Value');
        ROI = Model.ROIs(i).ROI;
        xyz = sim_getROI(Model.Pattern.mat,Model.Pattern.dim,ROI);  
    else
        xyz = [];
    end
else
    if length(ROIs)
        i = get(FS.LBoxROIMan,'Value');
        ROI = ROIs{i};
        xyz = sim_getROI(Model.Pattern.mat,Model.Pattern.dim,ROI);  
    else
        xyz = [];
    end
end
setappdata(FS.fig,'OV_pos',transform(ROI.parA))
oviews('init',p,800,xyz);
    
  
%%
%----------------------------------------------
% calls sim_evalScans which creates time series
%----------------------------------------------
function DO(hObject, eventdata)
FS = guidata(hObject);
sigpars = FS.sigpars;
Model = getappdata(FS.fig,'Model');
spm('CreateIntWin','on');
if Model.Noise.residn.consider
    spmFile = spm_select(1,'SPM.mat','Select SPM.mat file');
    ok = check_spmFile(spmFile,Model);
    if ok
        spm_input('','+1','d','Incompatible residual files!');
        if spm_input('Continue without adding residuals?','+1','y/n',[1,0],2)
            Model.Noise.residn.spmFile = '';
            Model.Noise.residn.consider = 0;
        else
            delete(spm_figure('FindWin','Interactive'));
            return
        end
    else
        Model.Noise.residn.spmFile = spmFile;
    end
end
delete(spm_figure('FindWin','Interactive'));
Model.File.dir = spm_select(1,'dir','Select directory to store scan files');
setappdata(FS.fig,'Model',Model);
save(fullfile(Model.File.dir,'model.mat'),'Model','sigpars')
sim_evalScans(Model);


%%
%------------------------
%------------------------
function Drift(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
temp = sscanf(get(hObject,'String'),'%f');
switch hObject
    case FS.EditDriftB
        if ~isempty(temp)
            Model.Noise.Drift.coef = temp;
            yDrift = 100*sim_trend(temp,Model.Features.nscan,Model.Noise.Drift.val);
            subplot(FS.AxesDrift), plot(getappdata(FS.fig,'Xaxis'),yDrift)
            set(FS.AxesDrift,'Color',[0.93 0.91 0.85])
            set(FS.AxesDrift,'Box','off')
            set(get(FS.AxesDrift,'XLabel'),'String','time [scan]')
            XLim = get(FS.AxesDrift,'XLim');
            YLim = get(FS.AxesDrift,'YLim');
            Ypos = YLim(1)+0.3*(YLim(2)-YLim(1));
            set(get(FS.AxesDrift,'XLabel'),'Position',[XLim(2) Ypos 1])
            set(get(FS.AxesDrift,'XLabel'),'HorizontalAlignment','right')
            set(get(FS.AxesDrift,'XLabel'),'BackGroundColor',getappdata(FS.fig,'ColorB'))
        end
        set(FS.EditDriftB,'String',sprintf('%g ',Model.Noise.Drift.coef));
        setappdata(FS.fig,'Model',Model)
    case FS.EditDriftA
        if ~isempty(temp)
            temp = temp(1);
            Model.Noise.Drift.val = temp;
            setappdata(FS.fig,'Model',Model)
            Drift(FS.EditDriftB)
        end
        set(FS.EditDriftA,'String',sprintf('%0.3g ',Model.Noise.Drift.val));
end



%%
%------------------------
%------------------------
function Noise(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
temp = sscanf(get(hObject,'String'),'%f');
if ~isempty(temp)
    temp = temp(1);
    switch hObject
        case FS.EditlfnOC
            Model.Noise.lfn.val = temp;
        case FS.EditlfnCOf
            Model.Noise.lfn.cutoff = temp;            
        case FS.Editlfnw
            Model.Noise.lfn.w = temp;
        case FS.EditgnOC
            Model.Noise.gn.val = temp;            
        case FS.Editgnw
            Model.Noise.gn.w = temp;
        case FS.Editresidnval
            Model.Noise.residn.val = temp;
        case FS.EditAr
            Model.Noise.Ar.val = temp;
        case FS.Edith1
            Model.Noise.Ar.h1 = temp;
        case FS.Edith2
            Model.Noise.Ar.h2 = temp;
    end
else
    switch hObject
        case FS.EditlfnOC
            temp = Model.Noise.lfn.val;
        case FS.EditlfnCOf
            temp = Model.Noise.lfn.cutoff;            
        case FS.Editlfnw
            temp = Model.Noise.lfn.w;
        case FS.EditgnOC
            temp = Model.Noise.gn.val;            
        case FS.Editgnw
            temp = Model.Noise.gn.w;
        case FS.Editresidnval
            temp = Model.Noise.residn.val;
        case FS.EditAr
            temp = Model.Noise.Ar.val;
        case FS.Edith1
            temp = Model.Noise.Ar.h1;
        case FS.Edith2
            temp = Model.Noise.Ar.h2;
    end
end
set(hObject,'String',sprintf('%g',temp));
setappdata(FS.fig,'Model',Model)


%%
%------------------------
%------------------------
function RBNoise(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
value = get(hObject,'Value');
switch hObject
    case FS.ChBDrift
        Model.Noise.Drift.consider = value;
    case FS.ChBlfn
        Model.Noise.lfn.consider = value;
    case FS.ChBgn
        Model.Noise.gn.consider = value;
    case FS.ChBresidn
        Model.Noise.residn.consider = value;
    case FS.ChBAr
        Model.Noise.Ar.consider = value;
end
guidata(FS.fig,FS)
setappdata(FS.fig,'Model',Model)


%%
%------------------------
%------------------------
function SaveImgs(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
value = get(hObject,'Value');
switch hObject
    case FS.ChBSigImgs
        Model.File.saveSigImgs = value;
    case FS.ChBNoiseImgs
        Model.File.saveNoiseImgs = value;
    case FS.ChBResidImgs
        Model.File.saveResidImgs = value;
end
setappdata(FS.fig,'Model',Model);


%%
%------------------------
%------------------------
function Prefix(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
temp = get(FS.EditPrefix,'String');
if sum([findstr(temp,'.') findstr(temp,'/') findstr(temp,'\') findstr(temp,'*') findstr(temp,' ') findstr(temp,'~') findstr(temp,'?')]) | isempty(temp)
    set(FS.EditPrefix,'String','fMRI_');
    Model.File.prefix = 'fMRI_';
    setappdata(FS.fig,'Model',Model);
    return
end
set(FS.EditPrefix,'String',temp);
Model.File.prefix = temp;
setappdata(FS.fig,'Model',Model);



%%
%------------------------
%------------------------
function GScaleVal(hObject, eventdata)
FS = guidata(hObject);
Model = getappdata(FS.fig,'Model');
temp = sscanf(get(FS.EditGScale,'String'),'%d');
if isempty(temp)
    set(FS.EditGScale,'String','100');
    Model.Features.GI = 100;
    setappdata(FS.fig,'Model',Model);
    return
end
temp = abs(temp(1));
if temp==0
    temp = 100;
end
set(FS.EditGScale,'String',sprintf('%d',temp));
Model.Features.GI = temp;
setappdata(FS.fig,'Model',Model);



%%
%------------------------------------------------------
% loads mat-file containing appropriate data structure
% user then can arbitrary change the settings
%------------------------------------------------------
function LoadModel(hObject, eventdata)
FS = guidata(hObject);
try
    model = spm_select(1,'*model.mat','Select file with model information');
    load(model);
catch
    return;
end
setappdata(FS.fig,'Model',model);
FS.sigpars = sigpars;


if isfield(model,'X')
    for i = 1:length(model.X(1,:))
        regNames{i} = ['r' sprintf('%d',i)];
    end
    set(FS.LBoxCol,'Value',1);
    set(FS.LBoxCol,'String',[]);
    set(FS.LBoxCol,'String',char(regNames));
    if strcmp(model.Pattern.fname,'defined space')
        set(FS.EditPatSpd,'String',sprintf('%d ',model.Pattern.dim(1:3)))
        set(FS.EditPatSpvs,'String',sprintf('%d ',[model.Pattern.mat(1,1) model.Pattern.mat(2,2) model.Pattern.mat(3,3)]))
        set(FS.EditPatSpc,'String',sprintf('%d ',[model.Pattern.mat(1,4)/-model.Pattern.mat(1,1) model.Pattern.mat(2,4)/-model.Pattern.mat(2,2) model.Pattern.mat(3,4)/-model.Pattern.mat(3,3)]))    
        ChBoxPatFileSd(FS.RBPatSp, [])
    else
        set(FS.EditPatFile,'String',model.Pattern.fname)
        ChBoxPatFileSd(FS.RBPatFile, [])
    end
    setappdata(FS.fig,'Xaxis',model.Features.RT*[0:model.Features.nscan-1])
    try
        delete(FS.AxesCol_LBoxColLine)
        delete(FS.AxesCol_LBoxROIModLine)
        guidata(FS.fig,FS)
    end
    Column(FS.LBoxCol)
else
    try
        delete(FS.AxesCol_LBoxColLine)
        delete(FS.AxesCol_LBoxROIModLine)
        guidata(FS.fig,FS)
    end
end


set(FS.EditDriftA,'String',sprintf('%g',model.Noise.Drift.val));
set(FS.EditDriftB,'String',sprintf('%g ',model.Noise.Drift.coef));
set(FS.EditlfnOC,'String',sprintf('%g',model.Noise.lfn.val));
set(FS.EditlfnCOf,'String',sprintf('%g',model.Noise.lfn.cutoff));
set(FS.Editlfnw,'String',sprintf('%g',model.Noise.lfn.w));
set(FS.EditgnOC,'String',sprintf('%g',model.Noise.gn.val));
set(FS.Editgnw,'String',sprintf('%g',model.Noise.gn.w));
set(FS.Editresidnval,'String',sprintf('%g',model.Noise.residn.val));
set(FS.ChBDrift,'value',model.Noise.Drift.consider);
set(FS.ChBgn,'value',model.Noise.gn.consider);
set(FS.ChBlfn,'value',model.Noise.lfn.consider);
set(FS.ChBresidn,'value',model.Noise.residn.consider);
set(FS.ButModManDO,'Enable','on');
set(FS.ButROIToMod,'Enable','on');

ReadModROIs
Drift(FS.EditDriftA)


%%
%------------------------------------------------------
% save mat-file containing current settings
%------------------------------------------------------
function SaveModel(hObject, eventdata)
FS = guidata(hObject);
model = getappdata(FS.fig,'Model');
sigpars = FS.sigpars;
spm('CreateIntWin','off');
fname = [spm_input('name of mat file',1,'s','model') '.mat'];
delete(spm_figure('FindWin','Interactive'));
fdir = spm_select(1,'dir','Select directory to store settings.');
save(fullfile(fdir,fname),'model','sigpars')



%%
%------------------------
%------------------------
function [result] = check_spmFile(spmFile,model)
load(spmFile);
result = (model.Pattern.dim ~= SPM.Vbeta(1).dim);



%%
%------------------------
%------------------------
function varargout = oviews(action,varargin)
FS = guidata(gcf);

if nargin > 3
    eval('setappdata(FS.fig,''OV_xyz'',[])');
    eval('setappdata(FS.fig,''OV_xyz'',varargin{3})');
end
if nargin < 1
    return
end

switch action
    
    case 'init'
        try
            if isstruct(varargin{1})
                eval('setappdata(FS.fig,''OV_image'',varargin{1})');
                eval('setappdata(FS.fig,''OV_pattern'',0)');
                eval('setappdata(FS.fig,''OV_imgData'',ones(varargin{1}.dim(1:3)))');
            else
                eval('setappdata(FS.fig,''OV_image'',spm_vol(varargin{1}))');
                eval('setappdata(FS.fig,''OV_pattern'',1)');
            end
        catch
            warndlg('Error on loading *.img file..','ERROR');
            return
        end
        
        temp = getappdata(FS.fig,'OV_image');
        eval('setappdata(FS.fig,''OV_dim'',temp.dim(1:3))');
        eval('setappdata(FS.fig,''OV_pos'',oviews(''transform'',[0 0 0]))');
        eval('setappdata(FS.fig,''OV_voxdim'',[temp.mat(1,1) temp.mat(2,2) temp.mat(3,3)])');
   
        viewWidth = 100; viewHeigh = 100;
        viewPos = [ 560 ];
        viewDim = abs(getappdata(FS.fig,'OV_dim').*getappdata(FS.fig,'OV_voxdim'));
        scale = viewWidth/max(viewDim);
        sviewDim = scale*viewDim;
        adjustedViewPos{1} = [ viewPos 520-sviewDim(1) [sviewDim(2) sviewDim(1)]];
        adjustedViewPos{2} = [ viewPos 520-sviewDim(1)-sviewDim(3)-10  [sviewDim(2) sviewDim(3)]];
        adjustedViewPos{3} = [ viewPos+10+sviewDim(2) 520-sviewDim(1) [sviewDim(3) sviewDim(1)]];
         
        set(FS.OV_Axes1,'Position',abs(adjustedViewPos{1}));
        set(FS.OV_Axes2,'Position',abs(adjustedViewPos{2}));
        set(FS.OV_Axes3,'Position',abs(adjustedViewPos{3}));
        
        redrawall;
        
        
    case 'ChangePos1'
        pos = get(FS.OV_Axes1,'CurrentPoint');
        OV_pos = getappdata(FS.fig,'OV_pos');
        OV_pos(1) = round(pos(1,2));
        OV_pos(2) = round(pos(1,1));
        eval('setappdata(FS.fig,''OV_pos'',OV_pos)');
        redrawall;
        
        
    case 'ChangePos2'
        pos = get(FS.OV_Axes2,'CurrentPoint');
        OV_pos = getappdata(FS.fig,'OV_pos');
        OV_dim = getappdata(FS.fig,'OV_dim');
        OV_pos(3) = OV_dim(3) - round(pos(1,2)) + 1;
        OV_pos(2) = round(pos(1,1));
        eval('setappdata(FS.fig,''OV_pos'',OV_pos)');
        redrawall;
        
        
    case 'ChangePos3'
        pos = get(FS.OV_Axes3,'CurrentPoint');
        OV_pos = getappdata(FS.fig,'OV_pos');
        OV_dim = getappdata(FS.fig,'OV_dim');
        OV_pos(3) = OV_dim(3) - round(pos(1,1)) + 1;
        OV_pos(1) = round(pos(1,2));
        eval('setappdata(FS.fig,''OV_pos'',OV_pos)');
        redrawall;
        
    case 'ChangeMm'
        OV_pos = getappdata(FS.fig,'OV_pos');
        OV_dim = getappdata(FS.fig,'OV_dim');
        num{1} = sscanf(get(FS.OV_EditMmX,'String'),'%f',1);
        num{2} = sscanf(get(FS.OV_EditMmY,'String'),'%f',1);
        num{3} = sscanf(get(FS.OV_EditMmZ,'String'),'%f',1);
        if ~isempty(num{1}) & ~isempty(num{2}) & ~isempty(num{3})
            pos = oviews('transform',[num{1} num{2} num{3}]);
            for i = 1:3
                if pos(i) < 1
                    OV_pos(i) = 1;
                elseif pos(i) > OV_dim(i)
                    OV_pos(i) = OV_dim(i);
                else
                    OV_pos(i) = pos(i);
                end
            end
        end
        eval('setappdata(FS.fig,''OV_pos'',OV_pos)');
        redrawall;
        
       
    case 'load'
        pattern = spm_select(1,'image','Select pattern scan');
        oviews('init',pattern);
        
    case 'redraw'
        redrawall;
        
    case 'transform'
        temp = getappdata(FS.fig,'OV_image');
        p = round(inv(temp.mat)*[varargin{1}';1]);
        varargout{1} = p(1:3)';
        
    case 'itransform'
        temp = getappdata(FS.fig,'OV_image');
        p = temp.mat*[varargin{1}';1];
        varargout{1} = p(1:3)';
end


%%
%%----------
%%----------
function OVclick(hObject, eventdata)
FS = guidata(hObject);
switch hObject
    case {FS.OV_img(1), FS.OV_lx(1), FS.OV_ly(1)}
        oviews('ChangePos1');
    case {FS.OV_img(2), FS.OV_lx(2), FS.OV_ly(2)}
        oviews('ChangePos2');
    case {FS.OV_img(3), FS.OV_lx(3), FS.OV_ly(3)}
        oviews('ChangePos3');
    case {FS.OV_EditMmX, FS.OV_EditMmY, FS.OV_EditMmZ}
        oviews('ChangeMm');
end
        


%%
%%----------
%%----------
function redraw(v)
FS = guidata(gcf);
AP = getappdata(FS.fig);
pos =round(AP.OV_pos);
if isfield(AP,'OV_xyz')
    xyz = AP.OV_xyz;
else
    xyz = [];
end
switch v
    case 1
        if AP.OV_pattern
            A = [ 1   0   0   0;
                  0   1   0   0;
                  0   0   1  pos(3);
                  0   0   0   1 ];
            img = spm_slice_vol(AP.OV_image,A,[AP.OV_dim(1) AP.OV_dim(2)],1); 
        else
            img = AP.OV_imgData(:,:,pos(3));
        end
        m = 1.5*max(max(img));
        ind = [];
        if ~isempty(xyz), ind = find(xyz(:,3) == pos(3)); end
        for i = 1:length(ind)
            img(xyz(ind(i),1),xyz(ind(i),2)) = m;
        end
        ax = FS.OV_Axes1;
    case 2
        if AP.OV_pattern
            A = [ 0   0   1   pos(1);
                  0   1   0   0;
                  -1   0   0   AP.OV_dim(3)+1;
                  0   0   0   1 ];
            img = spm_slice_vol(AP.OV_image,A,[AP.OV_dim(3) AP.OV_dim(2)],1); 
        else
            img = (squeeze(AP.OV_imgData(pos(1),:,:)))';
        end
        m = 1.5*max(max(img));
        ind = [];
        if ~isempty(xyz),ind = find(xyz(:,1) == pos(1)); end
        for i = 1:length(ind)
            img(AP.OV_dim(3)-xyz(ind(i),3)+1,xyz(ind(i),2)) = m;
        end
        ax = FS.OV_Axes2;
    case 3
        if AP.OV_pattern
            A = [ 1   0   0   0;
                  0   0   1   pos(2);
                  0   -1  0  AP.OV_dim(3)+1;
                  0   0   0   1 ];
            img = spm_slice_vol(AP.OV_image,A,[AP.OV_dim(1) AP.OV_dim(3)],1); 
        else
            img = squeeze(AP.OV_imgData(:,pos(2),:));
        end
        m = 1.5*max(max(img));
        ind = [];
        if ~isempty(xyz), ind = find(xyz(:,2) == pos(2)); end
        for i = 1:length(ind)
            img(xyz(ind(i),1),AP.OV_dim(3)-xyz(ind(i),3)+1) = m;
        end
        ax = FS.OV_Axes3;
end
figure(FS.fig), subplot(ax), FS.OV_img(v) = imagesc(img); colormap(gray)
guidata(FS.fig,FS)
set(FS.OV_img(v),'ButtonDownFcn',@OVclick);
set(ax,'XTick',[]);
set(ax,'YTick',[]);
set(ax,'ZTick',[]);
switch v
    case 1
        draw_lines(AP.OV_dim(1),AP.OV_dim(2),pos(1),pos(2),1);   
    case 2
        draw_lines(AP.OV_dim(3),AP.OV_dim(2),AP.OV_dim(3)-pos(3)+1,pos(2),2);
    case 3
        draw_lines(AP.OV_dim(1),AP.OV_dim(3),pos(1),AP.OV_dim(3)-pos(3)+1,3);
end



%%
%%----------
%%----------
function redrawall
FS = guidata(gcf);
AP = getappdata(FS.fig);
pos =round(AP.OV_pos);
ind = find(pos>AP.OV_dim);
if ~isempty(ind)
    for i = 1:length(ind)
        pos(ind(i)) = ceil(size(AP.OV_imgData,ind(i))/2);
    end
    OV_pos = pos;
    eval('setappdata(FS.fig,''OV_pos'',OV_pos)');
end
redraw(1); redraw(2); redraw(3);
FS = guidata(gcf);
pos = oviews('itransform',getappdata(FS.fig,'OV_pos'));
set(FS.OV_EditMmX,'String',sprintf('%0.3g',pos(1)));
set(FS.OV_EditMmY,'String',sprintf('%0.3g',pos(2)));
set(FS.OV_EditMmZ,'String',sprintf('%0.3g',pos(3)));


%%
%-------------------
%-------------------
function draw_lines(dy,dx,y,x,v)
FS = guidata(gcf);
FS.OV_ly(v) = line([x,x],[1,dy]);
FS.OV_lx(v) = line([1,dx],[y,y]);
set(FS.OV_ly(v),'Color','b');
set(FS.OV_lx(v),'Color','b');
set(FS.OV_ly(v),'ButtonDownFcn',@OVclick);
set(FS.OV_lx(v),'ButtonDownFcn',@OVclick);
guidata(FS.fig,FS);


%%
%------------------------------------------
%-----------------------------------------
function  xyz   =  CenterOfGravity(f, XYZ)
% returns centre of gravity of the discrete defined solid

if (length(f) ~= length(XYZ(:,1))) | (length(XYZ(1,:)) ~= 3) %| sum(f<0)
    xyz = NaN;
    return
end

M = sum(f);
Syz = sum(f.*XYZ(:,1));
Sxz = sum(f.*XYZ(:,2));
Sxy = sum(f.*XYZ(:,3));

xyz(1) = Syz/M;
xyz(2) = Sxz/M;
xyz(3) = Sxy/M;