function [ny, ScR] = sim_getRes(SPMfile,dir,prefix)
% ----------------------------------------------------
%   Computes residuals of GLM  
%   residual = Y - Xb
% ------------------------------------------------------

SPMdir = SPMfile(1:end-8);
cd(SPMdir);

load SPM.mat
  
K = SPM.xX.K;
X = SPM.xX.X;
W = SPM.xX.W;
VY = SPM.xY.VY;
Vbeta = SPM.Vbeta;
if isstruct(SPM.xX.K)
    filval = SPM.xX.K.HParam;
else
    filval = Inf;
end

Finter = spm('CreateIntWin','on');
set(Finter,'Name','Estimating residuals from GLM')

descrip = 'residual data';

fil = isfinite(filval);
AR =  fil & sum(W*W - W);

ny = length(VY);
nb = length(Vbeta);
beta = cell(1,length(Vbeta));

%-- loading beta images ----
for i = 1:nb;
    beta{i} = spm_read_vols(Vbeta(i));
end
xdim = Vbeta(1).dim(1);
ydim = Vbeta(1).dim(2);
zdim = Vbeta(1).dim(3);
M = Vbeta(1).mat;


cd(dir);
%----Intialise residual image files
Vres(1:length(VY)) = deal(struct(...
			'fname',	[],...
			'dim',		[xdim ydim zdim ,spm_type('float')],...
			'mat',		M,...
			'pinfo',	[1 0 0]',...
			'descrip',	descrip,...
            'n',        [],...
            'private',  []));
for i = 1:length(VY)
	Vres(i).fname   = [prefix '_res_' sprintf('%04d.img',i)];
	spm_unlink(Vres(i).fname)
Vres(i)         = spm_create_vol(Vres(i));
end



%-- computing ----
KX = spm_filter(K,X);
WX = W*X;
KWX = spm_filter(K,WX);
amp = [];

spm_progress_bar('Init',zdim,'Planes computed','')
for i = 1:zdim
    
    % indexes of non NaN voxels of beta files in current plane
    ind = find(~isnan(beta{1}(:,:,i)));
    indNaN = find(isnan(beta{1}(:,:,i)));
    
    sYNaN = floor((indNaN-1)/xdim)+1;
    sXNaN = indNaN - (sYNaN-1)*xdim;   
    yNaN = zeros(ny,length(indNaN));
    
    % load time series of out-mask voxels from current plane
    for ii = 1:ny
        yNaN(ii,:) = spm_sample_vol(VY(ii),sXNaN,sYNaN,i*ones(length(indNaN),1),0)';
    end
    meanNaN = mean(yNaN);
    % subtract a mean value from the time series of out-mask voxels
    for ii = 1:length(indNaN)
        yNaN(:,ii) = yNaN(:,ii) - meanNaN(ii);
    end
    
    amp = [amp max(yNaN)-min(yNaN)];
    
    
    if ~isempty(ind)
        sY = floor((ind-1)/xdim)+1;
        sX = ind - (sY-1)*xdim;
        y = zeros(ny,length(ind));
        b = zeros(nb,length(ind));
        
        % load time series of in-mask voxels from current plane 
        for ii = 1:ny
            y(ii,:) = spm_sample_vol(VY(ii),sX,sY,i*ones(length(ind),1),0)'; 
        end
        
        % load beta values
        for ii = 1:nb
            btemp = beta{ii}(:,:,i);
            b(ii,:) = btemp(ind)';
        end
        
        % filtering and weighting
        if AR & fil
            xX = KWX;
            y = spm_filter(K,W*y);
        elseif AR                
            xX = WX;
            y = W*y;
        elseif fil
            xX = KX;
            y = spm_filter(K,y);
        else
            xX = X;
        end
        
        % estimateting residuals
        temp = y - xX*b;
        
        amp = [amp max(temp)-min(temp)];
    end
    
    
    % writing plane
    A = eye(4); A(3,4) = i;
    
    for ii = 1:ny
        res = zeros(xdim,ydim);
        res(indNaN) = yNaN(ii,:);
        if ~isempty(ind)
            res(ind) = temp(ii,:);
        end
        spm_write_plane(Vres(ii),res,i);
    end
    
    spm_progress_bar('Set',i)
end   
spm_progress_bar('Clear')
delete(spm_figure('FindWin','Interactive'));

ScR = median(amp);

for i = 1:length(VY)
    spm_close_vol(Vres(i));
end