function sim_getSignals(varargin)


if ~strcmp(varargin{1},'end')
    if nargin == 3
        InitFig(varargin{1},varargin{2},varargin{3})
    else
        InitFig(varargin{1},varargin{2},[])
    end
else
    h = guidata(gcf);
    ch = guidata(h.parfig);
    [sig sigpars] = get_outvars(gcf);
    ch.sig = sig;
    ch.sigpars = sigpars;
    guidata(h.parfig,ch)
    uiresume(h.parfig)
    delete(h.fig)
end


function InitFig(fig,ch,pars)

parpos = get(ch,'Position');
%%
%--------  overall constants  ------------
ColorA = [0.8 0.8 0.8];
ColorB = [0.93 0.91 0.85];
ButtDim = [ 100 35 ];


%%
%---------  figure features  -------------

figWidth = 610;
figHeigh = 620;
figPos = [ parpos(1)+120 parpos(2)+50 figWidth figHeigh];

h.fig = fig;

set(fig,'Unit','pixel','WindowStyle','normal','Position',figPos,'Resize','off','Name','Signal Definition',...
    'NumberTitle','off','Color',ColorB,'CloseRequestFcn',@figClose);

%%
%--------- main uicontrols ----------------

PanBasPos = [10 520 590 90];
TextNSPos = [10 45 90 19];
EditNSPos = [105 45 50 21];
TextTRPos = [10 15 90 19];
EditTRPos = [105 15 50 21];
TextNSigPos = [170 45 90 19];
EditNSigPos = [265 45 50 21];
TextOnPos = [170 15 90 19];
EditOnPos = [265 15 300 21];
TextSNumPos = [330 45 90 19];
PopUpSNumPos = [410 45 50 21];
TextSTypePos = [470 45 90 19];
PopUpSTypePos = [505 45 60 21];


h.PanBas = uipanel('Parent',h.fig,'Units','pixel','Position',PanBasPos,'Title','Basic definition','FontWeight','bold','Visible','on');
h.TextNS = uicontrol('Parent',h.PanBas,'Units','pixel','Style','text','Position',TextNSPos,'String','Number of scans','HorizontalAlignment','left');
h.EditNS = uicontrol('Parent',h.PanBas,'Units','pixel','Style','edit','Position',EditNSPos,'String','100','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextTR = uicontrol('Parent',h.PanBas,'Units','pixel','Style','text','Position',TextTRPos,'String','TR [s]','HorizontalAlignment','left');
h.EditTR = uicontrol('Parent',h.PanBas,'Units','pixel','Style','edit','Position',EditTRPos,'String','3','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextNSig = uicontrol('Parent',h.PanBas,'Units','pixel','Style','text','Position',TextNSigPos,'String','Number of signals','HorizontalAlignment','left');
h.EditNSig = uicontrol('Parent',h.PanBas,'Units','pixel','Style','edit','Position',EditNSigPos,'String','1','HorizontalAlignment','left','BackGroundColor','w','CallBack',@NSig);
h.TextOn = uicontrol('Parent',h.PanBas,'Units','pixel','Style','text','Position',TextOnPos,'String','Onsets [scan]','HorizontalAlignment','left');
h.EditOn = uicontrol('Parent',h.PanBas,'Units','pixel','Style','edit','Position',EditOnPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangeOns);
h.TextSNum = uicontrol('Parent',h.PanBas,'Units','pixel','Style','text','Position',TextSNumPos,'String','Signal Number','HorizontalAlignment','left');
h.PopUpSNum = uicontrol('Parent',h.PanBas,'Units','pixel','Style','popupmenu','Position',PopUpSNumPos,'String','sig 1','HorizontalAlignment','left','BackGroundColor','w','Value',1,'CallBack',@PopUpSNum);
h.TextSType = uicontrol('Parent',h.PanBas,'Units','pixel','Style','text','Position',TextSTypePos,'String','Type','HorizontalAlignment','left');
h.PopUpSType = uicontrol('Parent',h.PanBas,'Units','pixel','Style','popupmenu','Position',PopUpSTypePos,'String',{'gauss' 'logit' 'arbitrary'},'HorizontalAlignment','left','BackGroundColor','w','Value',1,'CallBack',@PopUpSType);



%%
%----------  gauss signal type -------
PanGausPos = [10 135 590 370];
TextP1Pos = [10 325 130 19];
EditP1Pos = [150 325 50 21];
TextPar11Pos = [230 325 50 19];
EditPar11Pos = [300 325 50 21];
TextPar12Pos = [230 295 50 19];
EditPar12Pos = [300 295 50 21];
TextP1eqPos = [10 295 180 19];
AxesP1Pos = [380 295 195 50];
TextP6Pos = [10 240 130 19];
EditP6Pos = [150 240 50 21];
TextPar61Pos = [230 240 50 19];
EditPar61Pos = [300 240 50 21];
TextPar62Pos = [230 210 50 19];
EditPar62Pos = [300 210 50 21];
TextStd6Pos = [230 180 50 19];
EditStd6Pos = [300 180 50 21];
TextP6eqPos = [10 210 180 19];
AxesP6Pos = [380 180 195 70];
TextMPos = [10 125 130 19];
TextPar1MPos = [230 125 50 19];
EditPar1MPos = [300 125 50 21];
TextStdMPos = [230 95 50 19];
EditStdMPos = [300 95 50 21];
TextMeqPos = [10 95 180 19];
AxesMPos = [380 95 195 50];
TextP2Pos = [10 40 200 19];
EditP2Pos = [200 40 50 21];
TextP3Pos = [10 10 160 19];
EditP3Pos = [200 10 50 21];
TextP4Pos = [300 40 170 19];
EditP4Pos = [490 40 50 21];
TextP5Pos = [300 10 170 19];
EditP5Pos = [490 10 50 21];

h.PanGaus = uipanel('Parent',h.fig,'Units','pixel','Position',PanGausPos,'Title','2 Gauss Signal Type','FontWeight','bold');
h.TextP1 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextP1Pos,'String','Delay of response (p1)','HorizontalAlignment','left','FontWeight','bold');
h.EditP1 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditP1Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextPar11 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextPar11Pos,'String','par1 (p1)','HorizontalAlignment','left');
h.EditPar11 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditPar11Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextPar12 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextPar12Pos,'String','par2 (p1)','HorizontalAlignment','left');
h.EditPar12 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditPar12Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextP1eq = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextP1eqPos,'String','pp1 = par1*exp(-par2*dt)+p1','HorizontalAlignment','left');
h.AxesP1 = axes('Parent',h.PanGaus,'Units','Pixels','Position',AxesP1Pos,'Visible','on');
h.TextP6 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextP6Pos,'String','Onset (p6)','HorizontalAlignment','left','FontWeight','bold');
h.EditP6 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditP6Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextPar61 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextPar61Pos,'String','par1 (p6)','HorizontalAlignment','left');
h.EditPar61 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditPar61Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextPar62 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextPar62Pos,'String','par2 (p6)','HorizontalAlignment','left');
h.EditPar62 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditPar62Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextStd6 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextStd6Pos,'String','std of p6','HorizontalAlignment','left');
h.EditStd6 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditStd6Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextP6eq = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextP6eqPos,'String','pp6 = par1*exp(-par2*dt)+p6','HorizontalAlignment','left');
h.AxesP6 = axes('Parent',h.PanGaus,'Units','Pixels','Position',AxesP6Pos,'Visible','on');
h.TextM = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextMPos,'String','Magnitude','HorizontalAlignment','left','FontWeight','bold');
h.TextPar1M = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextPar1MPos,'String','par1 (m)','HorizontalAlignment','left');
h.EditPar1M = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditPar1MPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextStdM = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextStdMPos,'String','std of m','HorizontalAlignment','left');
h.EditStdM= uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditStdMPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextMeq = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextMeqPos,'String','m = 1-exp(-par1*dt)','HorizontalAlignment','left');
h.AxesM = axes('Parent',h.PanGaus,'Units','Pixels','Position',AxesMPos,'Visible','on');
h.TextP2 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextP2Pos,'String','Delay of undershoot (p2)','HorizontalAlignment','left','FontWeight','bold');
h.EditP2 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditP2Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextP3 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextP3Pos,'String','Dispersion of response (p3)','HorizontalAlignment','left','FontWeight','bold');
h.EditP3 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditP3Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextP4 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextP4Pos,'String','Dispersion of undershoot (p4)','HorizontalAlignment','left','FontWeight','bold');
h.EditP4 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditP4Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextP5 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','text','Position',TextP5Pos,'String','Ratio of resp / undershoot (p5)','HorizontalAlignment','left','FontWeight','bold');
h.EditP5 = uicontrol('Parent',h.PanGaus,'Units','pixel','Style','edit','Position',EditP5Pos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);

%%
%----------  arbitrary signal type -------
PanASPos = [10 135 590 370];
TextHrfASPos = [10 325 130 19];
EditHrfASPos = [10 295 250 21];
AxesHrfASPos = [300 295 275 50];
TextOnASPos = [10 240 130 19];
EditOnASPos = [150 240 50 21];
TextPar1OnASPos = [230 240 50 19];
EditPar1OnASPos = [300 240 50 21];
TextPar2OnASPos = [230 210 50 19];
EditPar2OnASPos = [300 210 50 21];
TextStdOnASPos = [230 180 50 19];
EditStdOnASPos = [300 180 50 21];
TextOnASeqPos = [10 210 180 19];
AxesOnASPos = [380 180 195 70];
TextMASPos = [10 125 130 19];
TextPar1MASPos = [230 125 50 19];
EditPar1MASPos = [300 125 50 21];
TextStdMASPos = [230 95 50 19];
EditStdMASPos = [300 95 50 21];
TextMASeqPos = [10 95 180 19];
AxesMASPos = [380 95 195 50];

h.PanAS = uipanel('Parent',h.fig,'Units','pixel','Position',PanASPos,'Title','Arbitrary Signal Type','FontWeight','bold','Visible','off');
h.TextHrfAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextHrfASPos,'String','Arbitrary HRF','HorizontalAlignment','left','FontWeight','bold');
h.EditHrfAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','edit','Position',EditHrfASPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@Hrf);
h.AxesHrfAS = axes('Parent',h.PanAS,'Units','Pixels','Position',AxesHrfASPos,'Visible','on');
h.TextOnAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextOnASPos,'String','Onset','HorizontalAlignment','left','FontWeight','bold');
h.EditOnAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','edit','Position',EditOnASPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextPar1OnAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextPar1OnASPos,'String','par1','HorizontalAlignment','left');
h.EditPar1OnAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','edit','Position',EditPar1OnASPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextPar2OnAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextPar2OnASPos,'String','par2 (p6)','HorizontalAlignment','left');
h.EditPar2OnAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','edit','Position',EditPar2OnASPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextStdOnAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextStdOnASPos,'String','std of p6','HorizontalAlignment','left');
h.EditStdOnAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','edit','Position',EditStdOnASPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextOnASeq = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextOnASeqPos,'String','ons = par1*exp(-par2*dt)+onset','HorizontalAlignment','left');
h.AxesOnAS = axes('Parent',h.PanAS,'Units','Pixels','Position',AxesOnASPos,'Visible','on');
h.TextMAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextMASPos,'String','Magnitude','HorizontalAlignment','left','FontWeight','bold');
h.TextPar1MAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextPar1MASPos,'String','par1 (m)','HorizontalAlignment','left');
h.EditPar1MAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','edit','Position',EditPar1MASPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextStdMAS = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextStdMASPos,'String','std of m','HorizontalAlignment','left');
h.EditStdMAS= uicontrol('Parent',h.PanAS,'Units','pixel','Style','edit','Position',EditStdMASPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextMASeq = uicontrol('Parent',h.PanAS,'Units','pixel','Style','text','Position',TextMASeqPos,'String','m = 1-exp(-par1*dt)','HorizontalAlignment','left');
h.AxesMAS = axes('Parent',h.PanAS,'Units','Pixels','Position',AxesMASPos,'Visible','on');

%%
%----------  arbitrary signal type -------
PanLPos = [10 135 590 370];
TextT1LPos = [10 325 50 19];
EditT1LPos = [100 325 50 21];
TextD1LPos = [10 295 50 19];
EditD1LPos = [100 295 50 21];
TextT2LPos = [10 265 50 19];
EditT2LPos = [100 265 50 21];
TextD2LPos = [10 235 50 19];
EditD2LPos = [100 235 50 21];
TextT3LPos = [185 325 50 19];
EditT3LPos = [275 325 50 21];
TextD3LPos = [185 295 50 19];
EditD3LPos = [275 295 50 21];
TextRatioLPos = [185 265 65 19];
EditRatioLPos = [275 265 50 21];
AxesHrfLPos = [380 215 195 130];
TextOnLPos = [10 160 130 19];
EditOnLPos = [150 160 50 21];
TextPar1OnLPos = [230 160 50 19];
EditPar1OnLPos = [300 160 50 21];
TextPar2OnLPos = [230 130 50 19];
EditPar2OnLPos = [300 130 50 21];
TextStdOnLPos = [230 100 50 19];
EditStdOnLPos = [300 100 50 21];
TextOnLeqPos = [10 130 180 19];
AxesOnLPos = [380 100 195 70];
TextMLPos = [10 45 130 19];
TextPar1MLPos = [230 45 50 19];
EditPar1MLPos = [300 45 50 21];
TextStdMLPos = [230 15 50 19];
EditStdMLPos = [300 15 50 21];
TextMLeqPos = [10 15 180 19];
AxesMLPos = [380 15 195 50];

h.PanL = uipanel('Parent',h.fig,'Units','pixel','Position',PanLPos,'Title','Logit Signal Type','FontWeight','bold','Visible','off');
h.TextT1L = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextT1LPos,'String','T1 [s]','HorizontalAlignment','left','FontWeight','bold');
h.EditT1L = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditT1LPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextD1L = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextD1LPos,'String','D1 [s]','HorizontalAlignment','left','FontWeight','bold');
h.EditD1L = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditD1LPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextT2L = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextT2LPos,'String','T2 [s]','HorizontalAlignment','left','FontWeight','bold');
h.EditT2L = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditT2LPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextD2L = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextD2LPos,'String','D2 [s]','HorizontalAlignment','left','FontWeight','bold');
h.EditD2L = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditD2LPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextT3L = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextT3LPos,'String','T3 [s]','HorizontalAlignment','left','FontWeight','bold');
h.EditT3L = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditT3LPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextD3L = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextD3LPos,'String','D3 [s]','HorizontalAlignment','left','FontWeight','bold');
h.EditD3L = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditD3LPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextRatioL = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextRatioLPos,'String','-alfa2/alfa1','HorizontalAlignment','left','FontWeight','bold');
h.EditRatioL = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditRatioLPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.AxesHrfL = axes('Parent',h.PanL,'Units','Pixels','Position',AxesHrfLPos,'Visible','on');
h.TextOnL = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextOnLPos,'String','Onset','HorizontalAlignment','left','FontWeight','bold');
h.EditOnL = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditOnLPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextPar1OnL = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextPar1OnLPos,'String','par1','HorizontalAlignment','left');
h.EditPar1OnL = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditPar1OnLPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextPar2OnL = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextPar2OnLPos,'String','par2 (p6)','HorizontalAlignment','left');
h.EditPar2OnL = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditPar2OnLPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextStdOnL = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextStdOnLPos,'String','std of p6','HorizontalAlignment','left');
h.EditStdOnL = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditStdOnLPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextOnLeq = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextOnLeqPos,'String','ons = par1*exp(-par2*dt)+onset','HorizontalAlignment','left');
h.AxesOnL = axes('Parent',h.PanL,'Units','Pixels','Position',AxesOnLPos,'Visible','on');
h.TextML = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextMLPos,'String','Magnitude','HorizontalAlignment','left','FontWeight','bold');
h.TextPar1ML = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextPar1MLPos,'String','par1 (m)','HorizontalAlignment','left');
h.EditPar1ML = uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditPar1MLPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextStdML = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextStdMLPos,'String','std of m','HorizontalAlignment','left');
h.EditStdML= uicontrol('Parent',h.PanL,'Units','pixel','Style','edit','Position',EditStdMLPos,'String','','HorizontalAlignment','left','BackGroundColor','w','Callback',@ChangePar);
h.TextMLeq = uicontrol('Parent',h.PanL,'Units','pixel','Style','text','Position',TextMLeqPos,'String','m = 1-exp(-par1*dt)','HorizontalAlignment','left');
h.AxesML = axes('Parent',h.PanL,'Units','Pixels','Position',AxesMLPos,'Visible','on');

%%
%------ other ------
AxesSigPos = [35 30 420 75];
ButtDonePos = [490 35 110 60];

h.AxesSig = axes('Parent',h.fig,'Units','Pixels','Position',AxesSigPos,'Visible','on');
h.ButtDone = uicontrol('Parent',h.fig,'Units','pixel','Style','pushbutton','Position',ButtDonePos,'String','DONE','Callback','sim_getSignals(''end'')');

%%
h.parfig = ch;
if ~isempty(pars)
    h.data = pars;
    set(h.EditNSig,'String',num2str(h.data.NSig))
    for ii = 1:h.data.NSig
        temp{ii} = ['sig ' num2str(ii)];
    end
    set(h.PopUpSNum,'String',char(temp))
    guidata(h.fig,h)
else
    guidata(h.fig,h)
    set_BasicDef_defaults(h.fig);
end
DispSig(h.fig,1);


%%
function set_BasicDef_defaults(figh)
h = guidata(figh);
set(h.EditNS,'string','100'); h.data.NS = 100;
set(h.EditTR,'string','3'); h.data.TR = 3;
set(h.EditNSig,'String','1'); h.data.NSig = 1;
set(h.PopUpSNum,'String','sig 1'); h.data.SNum = 1;
set(h.PopUpSType,'String',{'gauss' 'logit' 'arbitrary'});
set(h.PopUpSType,'Value',1); h.data.sig{1}.type = 'G';
set(h.EditOn,'String','1'); h.data.sig{1}.ons = 0;
h.data.sig{1}.pars = [];
guidata(h.fig,h)


%%
function h = set_2Gauss(h,n,def)
if def
    h.data.sig{n}.pars.P1 = 6;
    h.data.sig{n}.pars.Par11 = 0;
    h.data.sig{n}.pars.Par12 = 0.3;
    h.data.sig{n}.pars.P6 = 0;
    h.data.sig{n}.pars.Par61 = 0;
    h.data.sig{n}.pars.Par62 = 0.3;
    h.data.sig{n}.pars.Std6 = 0;
    h.data.sig{n}.pars.Par1M = inf;
    h.data.sig{n}.pars.StdM = 0;
    h.data.sig{n}.pars.P2 = 16;
    h.data.sig{n}.pars.P3 = 1;
    h.data.sig{n}.pars.P4 = 1;
    h.data.sig{n}.pars.P5 = 6;
end
set(h.EditP1,'string',num2str(h.data.sig{n}.pars.P1)); 
set(h.EditPar11,'string',num2str(h.data.sig{n}.pars.Par11)); 
set(h.EditPar12,'string',num2str(h.data.sig{n}.pars.Par12)); 
set(h.EditP6,'string',num2str(h.data.sig{n}.pars.P6)); 
set(h.EditPar61,'string',num2str(h.data.sig{n}.pars.Par61)); 
set(h.EditPar62,'string',num2str(h.data.sig{n}.pars.Par62)); 
set(h.EditStd6,'String',num2str(h.data.sig{n}.pars.Std6)); 
set(h.EditPar1M,'string',num2str(h.data.sig{n}.pars.Par1M)); 
set(h.EditStdM,'string',num2str(h.data.sig{n}.pars.StdM)); 
set(h.EditP2,'string',num2str(h.data.sig{n}.pars.P2)); 
set(h.EditP3,'string',num2str(h.data.sig{n}.pars.P3)); 
set(h.EditP4,'string',num2str(h.data.sig{n}.pars.P4)); 
set(h.EditP5,'string',num2str(h.data.sig{n}.pars.P5));
set(h.EditOn,'string',['[' num2str(h.data.sig{n}.ons) ']']);
set(h.EditNS,'string',num2str(h.data.NS));
set(h.EditTR,'string',num2str(h.data.TR));


%%
function h = set_AS(h,n,def)
if def
    h.data.sig{n}.pars.HrfAS = [0 1 1 0];
    h.data.sig{n}.pars.OnAS = 0;
    h.data.sig{n}.pars.Par1OnAS = 0;
    h.data.sig{n}.pars.Par2OnAS = 0.3;
    h.data.sig{n}.pars.StdOnAS = 0;
    h.data.sig{n}.pars.Par1MAS = inf;
    h.data.sig{n}.pars.StdMAS = 0;
end
set(h.EditHrfAS,'string',num2str(h.data.sig{n}.pars.HrfAS)); 
set(h.EditOnAS,'string',num2str(h.data.sig{n}.pars.OnAS)); 
set(h.EditPar1OnAS,'string',num2str(h.data.sig{n}.pars.Par1OnAS)); 
set(h.EditPar2OnAS,'string',num2str(h.data.sig{n}.pars.Par2OnAS)); 
set(h.EditStdOnAS,'String',num2str(h.data.sig{n}.pars.StdOnAS)); 
set(h.EditPar1MAS,'string',num2str(h.data.sig{n}.pars.Par1MAS)); 
set(h.EditStdMAS,'string',num2str(h.data.sig{n}.pars.StdMAS)); 
set(h.EditOn,'string',['[' num2str(h.data.sig{n}.ons) ']']);
set(h.EditNS,'string',num2str(h.data.NS));
set(h.EditTR,'string',num2str(h.data.TR));

%%
function h = set_L(h,n,def)
if def
    h.data.sig{n}.pars.T1L = 6;
    h.data.sig{n}.pars.D1L = 1;
    h.data.sig{n}.pars.T2L = 15;
    h.data.sig{n}.pars.D2L = 1.5;
    h.data.sig{n}.pars.T3L = 30;
    h.data.sig{n}.pars.D3L = 2;
    h.data.sig{n}.pars.RatioL = 1.05;
    h.data.sig{n}.pars.OnL = 0;
    h.data.sig{n}.pars.Par1OnL = 0;
    h.data.sig{n}.pars.Par2OnL = 0.3;
    h.data.sig{n}.pars.StdOnL = 0;
    h.data.sig{n}.pars.Par1ML = inf;
    h.data.sig{n}.pars.StdML = 0;
end
set(h.EditT1L,'string',num2str(h.data.sig{n}.pars.T1L)); 
set(h.EditD1L,'string',num2str(h.data.sig{n}.pars.D1L)); 
set(h.EditT2L,'string',num2str(h.data.sig{n}.pars.T2L)); 
set(h.EditD2L,'string',num2str(h.data.sig{n}.pars.D2L)); 
set(h.EditT3L,'string',num2str(h.data.sig{n}.pars.T3L)); 
set(h.EditD3L,'string',num2str(h.data.sig{n}.pars.D3L)); 
set(h.EditRatioL,'string',num2str(h.data.sig{n}.pars.RatioL)); 
set(h.EditOnL,'string',num2str(h.data.sig{n}.pars.OnL)); 
set(h.EditPar1OnL,'string',num2str(h.data.sig{n}.pars.Par1OnL)); 
set(h.EditPar2OnL,'string',num2str(h.data.sig{n}.pars.Par2OnL)); 
set(h.EditStdOnL,'String',num2str(h.data.sig{n}.pars.StdOnL)); 
set(h.EditPar1ML,'string',num2str(h.data.sig{n}.pars.Par1ML)); 
set(h.EditStdML,'string',num2str(h.data.sig{n}.pars.StdML)); 
set(h.EditOn,'string',['[' num2str(h.data.sig{n}.ons) ']']);
set(h.EditNS,'string',num2str(h.data.NS));
set(h.EditTR,'string',num2str(h.data.TR));

%%
function DispSig(figh,n)
h = guidata(figh);

switch h.data.sig{n}.type
    
    case 'G'
        set(h.PanGaus,'Visible','on');
        set(h.PanAS,'Visible','off');
        set(h.PanL,'Visible','off');
        set(h.PopUpSType,'Value',1)
        if ~isfield(h.data.sig{n}.pars,'P1')
            h = set_2Gauss(h,n,1);
        else
            set_2Gauss(h,n,0);
        end
        time = 0:0.01:32;
        pars = h.data.sig{n}.pars;
        pp1 = pars.Par11 * exp(-pars.Par12*time) + pars.P1;
        pp6 = pars.Par61 * exp(-pars.Par62*time) + pars.P6;
        m = 1 - exp(-pars.Par1M*time);
        axes(h.AxesP1), plot(time,pp1), set(h.AxesP1,'XLim',[0 32])
        axes(h.AxesP6), plot(time,pp6), set(h.AxesP6,'XLim',[0 32])
        axes(h.AxesM), plot(time,m), set(h.AxesM,'XLim',[0 32])
        
        sig = sim_get2GTimeCourse(h.data.TR,h.data.sig{n}.ons,h.data.NS,[pars.Par11 pars.Par12 pars.P1 pars.Par61 pars.Par62 pars.P6 pars.Std6 pars.Par1M pars.StdM pars.P2 pars.P3 pars.P4 pars.P5]);
        axes(h.AxesSig), plot(0:length(sig)-1,sig), set(h.AxesSig,'XLim',[0 h.data.NS])
        
    case 'A'
        set(h.PanGaus,'Visible','off');
        set(h.PanAS,'Visible','on');
        set(h.PanL,'Visible','off');
        set(h.PopUpSType,'Value',3)
        if ~isfield(h.data.sig{n}.pars,'HrfAS')
            h = set_AS(h,n,1);
        else
            set_AS(h,n,0);
        end
        time = 0:0.01:32;
        pars = h.data.sig{n}.pars;
        ons = pars.Par1OnAS * exp(-pars.Par2OnAS*time) + pars.OnAS;
        m = 1 - exp(-pars.Par1MAS*time);
        axes(h.AxesOnAS), plot(time,ons), set(h.AxesOnAS,'XLim',[0 32])
        axes(h.AxesMAS), plot(time,m), set(h.AxesMAS,'XLim',[0 32])
        axes(h.AxesHrfAS), plot(0:length(pars.HrfAS)-1,pars.HrfAS)
        
        sig = sim_getASTimeCourse(pars.HrfAS,h.data.TR,h.data.sig{n}.ons,h.data.NS,[pars.Par1OnAS pars.Par2OnAS pars.OnAS pars.StdOnAS pars.Par1MAS pars.StdMAS]);
        axes(h.AxesSig), plot(0:length(sig)-1,sig), set(h.AxesSig,'XLim',[0 h.data.NS])
        
    case 'L'
        set(h.PanGaus,'Visible','off');
        set(h.PanAS,'Visible','off');
        set(h.PanL,'Visible','on');
        set(h.PopUpSType,'Value',2)
        if ~isfield(h.data.sig{n}.pars,'T1L')
            h = set_L(h,n,1);
        else
            set_L(h,n,0);
        end
        time = 0:0.01:32;
        pars = h.data.sig{n}.pars;
        ons = pars.Par1OnL * exp(-pars.Par2OnL*time) + pars.OnL;
        m = 1 - exp(-pars.Par1ML*time);
        axes(h.AxesOnL), plot(time,ons), set(h.AxesOnL,'XLim',[0 32])
        axes(h.AxesML), plot(time,m), set(h.AxesML,'XLim',[0 32])
        s1 = logit((time-pars.T1L)/pars.D1L);
        s2 = -pars.RatioL*logit((time-pars.T2L)/pars.D2L);
        s3 = (pars.RatioL-1)*logit((time-pars.T3L)/pars.D3L);
        axes(h.AxesHrfL), plot(time,s1+s2+s3), set(h.AxesHrfL,'XLim',[0 32])

        sig = sim_getLogitTimeCourse(h.data.TR,h.data.sig{n}.ons,h.data.NS,[pars.T1L pars.D1L pars.T2L pars.D2L pars.T3L pars.D3L pars.RatioL pars.OnL pars.Par1OnL pars.Par2OnL pars.StdOnL pars.Par1ML pars.StdML]);
        axes(h.AxesSig), plot(0:length(sig)-1,sig), set(h.AxesSig,'XLim',[0 h.data.NS])
        
        
end

guidata(h.fig,h)


%%
function ChangePar(handle, eventdata)
h = guidata(handle);
temp = str2num(get(handle,'String'));
n = get(h.PopUpSNum,'Value');
if ~isempty(temp) & ~sum([temp 1]<0)
    switch handle
        case h.EditP1
            h.data.sig{n}.pars.P1 = temp(1); 
        case h.EditPar11
            h.data.sig{n}.pars.Par11 = temp(1);
        case h.EditPar12
            h.data.sig{n}.pars.Par12 = temp(1);
        case h.EditP6
            h.data.sig{n}.pars.P6 = temp(1);
        case h.EditPar61
            h.data.sig{n}.pars.Par61 = temp(1);
        case h.EditPar62
            h.data.sig{n}.pars.Par62 = temp(1);
        case h.EditStd6
            h.data.sig{n}.pars.Std6 = temp(1);
        case h.EditPar1M
            h.data.sig{n}.pars.Par1M = temp(1);
        case h.EditStdM
            h.data.sig{n}.pars.StdM = temp(1);
        case h.EditP2
            h.data.sig{n}.pars.P2 = temp(1);
        case h.EditP3
            h.data.sig{n}.pars.P3 = temp(1);
        case h.EditP4
            h.data.sig{n}.pars.P4 = temp(1);
        case h.EditP5
            h.data.sig{n}.pars.P5 = temp(1);
        case h.EditOnAS
            h.data.sig{n}.pars.OnAS = temp(1);            
        case h.EditPar1OnAS
            h.data.sig{n}.pars.Par1OnAS = temp(1);
        case h.EditPar2OnAS
            h.data.sig{n}.pars.Par2OnAS = temp(1);
        case h.EditStdOnAS
            h.data.sig{n}.pars.StdOnAS = temp(1);
        case h.EditPar1MAS
            h.data.sig{n}.pars.Par1MAS = temp(1);
        case h.EditStdMAS
            h.data.sig{n}.pars.StdMAS = temp(1);
        case h.EditT1L
            h.data.sig{n}.pars.T1L = temp(1);
        case h.EditD1L
            h.data.sig{n}.pars.D1L = temp(1);
        case h.EditT2L
            h.data.sig{n}.pars.T2L = temp(1);
        case h.EditD2L
            h.data.sig{n}.pars.D2L = temp(1);
        case h.EditT3L
            h.data.sig{n}.pars.T3L = temp(1);
        case h.EditD3L
            h.data.sig{n}.pars.D3L = temp(1);
        case h.EditRatioL
            h.data.sig{n}.pars.RatioL = temp(1);
        case h.EditOnL
            h.data.sig{n}.pars.OnL = temp(1);
        case h.EditPar1OnL
            h.data.sig{n}.pars.Par1OnL = temp(1);
        case h.EditPar2OnL
            h.data.sig{n}.pars.Par2OnL = temp(1);
        case h.EditStdOnL
            h.data.sig{n}.pars.StdOnL = temp(1);
        case h.EditPar1ML
            h.data.sig{n}.pars.Par1ML = temp(1);
        case h.EditStdML
            h.data.sig{n}.pars.StdML = temp(1);
        case h.EditNS
            if temp(1) == 0
                temp = 100;
            end
            h.data.NS = round(temp);
        case h.EditTR
            if temp(1) == 0
                temp = 3;
            end
            h.data.TR = temp;
    end
end
guidata(h.fig,h)
DispSig(h.fig,n)


%%
function ChangeOns(handle, eventdata)
h = guidata(handle);
try
    temp = eval(get(handle,'String'));
catch
    temp = 1;
end
n = get(h.PopUpSNum,'Value');
if ~isempty(temp)
    temp = sort(unique(temp));
    h.data.sig{n}.ons = temp;
end
guidata(h.fig,h)
DispSig(h.fig,n)


%%
function PopUpSNum(handle, eventdata)
h = guidata(handle);
n = get(handle,'Value');
DispSig(h.fig,n)


%%
function NSig(handle, eventdata)
h = guidata(handle);
temp = str2num(get(handle,'String'));
oldsn = length(h.data.sig);
if ~isempty(temp)
    sn = max([round(temp(1)) 1]);
    temp = h.data.sig;
    temps = [];
    h.data.sig = [];
    for ii = 1:sn
       if ii>oldsn
           h.data.sig{ii}.ons = 1;
           h.data.sig{ii}.type = 'G';
           h.data.sig{ii}.pars = [];
       else
           h.data.sig{ii} = temp{ii};
       end
       temps{ii} = ['sig ' num2str(ii)];
    end
    h.data.NSig = sn;
    set(h.PopUpSNum,'String',char(temps))
end
set(handle,'String',h.data.NSig);
set(h.PopUpSNum,'Value',1)
guidata(h.fig,h)
DispSig(h.fig,1)


%%
function [ s sp ] = get_outvars(handle)
h = guidata(handle);
for ii = 1:h.data.NSig
    pars = h.data.sig{ii}.pars;
    switch h.data.sig{ii}.type
        case 'G'
            if isfield(pars,'P1')
                s(:,ii) = sim_get2GTimeCourse(h.data.TR,h.data.sig{ii}.ons,h.data.NS,[pars.Par11 pars.Par12 pars.P1 pars.Par61 pars.Par62 pars.P6 pars.Std6 pars.Par1M pars.StdM pars.P2 pars.P3 pars.P4 pars.P5]);
            else
                s(:,ii) = 0;
            end
        case 'A'
            if isfield(pars,'HrfAS')
                s(:,ii) = sim_getASTimeCourse(pars.HrfAS,h.data.TR,h.data.sig{ii}.ons,h.data.NS,[pars.Par1OnAS pars.Par2OnAS pars.OnAS pars.StdOnAS pars.Par1MAS pars.StdMAS]);
            else
                s(:,ii) = 0;
            end
        case 'L'
            if isfield(pars,'T1L')
                s(:,ii) = sim_getLogitTimeCourse(h.data.TR,h.data.sig{ii}.ons,h.data.NS,[pars.T1L pars.D1L pars.T2L pars.D2L pars.T3L pars.D3L pars.RatioL pars.OnL pars.Par1OnL pars.Par2OnL pars.StdOnL pars.Par1ML pars.StdML]);
            else
                s(:,ii) = 0;
            end
    end
end
sp = h.data;

%%
function figClose(handle, eventdata)
h = guidata(handle);
try
    sim_getSignals('end')
catch
    delete(gcf)
end


%%
function PopUpSType(handle, eventdata)
h = guidata(handle);
n = get(h.PopUpSNum,'Value');
type = get(handle,'Value');
switch type
    case 1
        h.data.sig{n}.type = 'G';
    case 2
        h.data.sig{n}.type = 'L';
    case 3
        h.data.sig{n}.type = 'A';
    otherwise
        h.data.sig{n}.type = 'G';
end
guidata(h.fig,h)
DispSig(h.fig,n)

%%
function Hrf(handle, eventdata)
h = guidata(handle);
n = get(h.PopUpSNum,'Value');
temp = str2num(get(handle,'String'));
if ~isempty(temp)
    h.data.sig{n}.pars.HrfAS = temp;
end
guidata(h.fig,h)
DispSig(h.fig,n)

%%
function y = logit(x)
y = 1./(1+exp(-x));
